"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class SessionType(object):
    """Implementation of the 'SessionType' model.

    SessionType contains information about the session types in a business.

    Attributes:
        mtype (TypeEnum): Contains the class description session type. Possible
            values are:  * All  * Class  * Enrollment  * Appointment  * Resource  *
            Media  * Arrival
        default_time_length (int): The default amount of time that a session of this
            type typically lasts.
        staff_time_length (int): The amount of time that a session of this type will
            last for a specific Staff (when applicable.)
        id (int): This session type’s unique ID.
        name (str): The name of this session type.
        online_description (str): The online description associated with the
            appointment.
        num_deducted (int): The number of sessions that this session type deducts
            from the pricing option used to pay for this type of session.
        program_id (int): This session type’s service category ID.
        category (str): This session type’s category.
        category_id (int): This session type’s category ID.
        subcategory (str): This session type’s subcategory.
        subcategory_id (int): This session type’s subcategory ID.
        available_for_add_on (bool): This session type’s Add On Flag.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtype": "Type",
        "default_time_length": "DefaultTimeLength",
        "staff_time_length": "StaffTimeLength",
        "id": "Id",
        "name": "Name",
        "online_description": "OnlineDescription",
        "num_deducted": "NumDeducted",
        "program_id": "ProgramId",
        "category": "Category",
        "category_id": "CategoryId",
        "subcategory": "Subcategory",
        "subcategory_id": "SubcategoryId",
        "available_for_add_on": "AvailableForAddOn",
    }

    _optionals = [
        "mtype",
        "default_time_length",
        "staff_time_length",
        "id",
        "name",
        "online_description",
        "num_deducted",
        "program_id",
        "category",
        "category_id",
        "subcategory",
        "subcategory_id",
        "available_for_add_on",
    ]

    def __init__(
        self,
        mtype=APIHelper.SKIP,
        default_time_length=APIHelper.SKIP,
        staff_time_length=APIHelper.SKIP,
        id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        online_description=APIHelper.SKIP,
        num_deducted=APIHelper.SKIP,
        program_id=APIHelper.SKIP,
        category=APIHelper.SKIP,
        category_id=APIHelper.SKIP,
        subcategory=APIHelper.SKIP,
        subcategory_id=APIHelper.SKIP,
        available_for_add_on=APIHelper.SKIP):
        """Initialize a SessionType instance."""
        # Initialize members of the class
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype
        if default_time_length is not APIHelper.SKIP:
            self.default_time_length = default_time_length
        if staff_time_length is not APIHelper.SKIP:
            self.staff_time_length = staff_time_length
        if id is not APIHelper.SKIP:
            self.id = id
        if name is not APIHelper.SKIP:
            self.name = name
        if online_description is not APIHelper.SKIP:
            self.online_description = online_description
        if num_deducted is not APIHelper.SKIP:
            self.num_deducted = num_deducted
        if program_id is not APIHelper.SKIP:
            self.program_id = program_id
        if category is not APIHelper.SKIP:
            self.category = category
        if category_id is not APIHelper.SKIP:
            self.category_id = category_id
        if subcategory is not APIHelper.SKIP:
            self.subcategory = subcategory
        if subcategory_id is not APIHelper.SKIP:
            self.subcategory_id = subcategory_id
        if available_for_add_on is not APIHelper.SKIP:
            self.available_for_add_on = available_for_add_on

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        mtype =\
            dictionary.get("Type")\
            if dictionary.get("Type")\
                else APIHelper.SKIP
        default_time_length =\
            dictionary.get("DefaultTimeLength")\
            if dictionary.get("DefaultTimeLength")\
                else APIHelper.SKIP
        staff_time_length =\
            dictionary.get("StaffTimeLength")\
            if dictionary.get("StaffTimeLength")\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        online_description =\
            dictionary.get("OnlineDescription")\
            if dictionary.get("OnlineDescription")\
                else APIHelper.SKIP
        num_deducted =\
            dictionary.get("NumDeducted")\
            if dictionary.get("NumDeducted")\
                else APIHelper.SKIP
        program_id =\
            dictionary.get("ProgramId")\
            if dictionary.get("ProgramId")\
                else APIHelper.SKIP
        category =\
            dictionary.get("Category")\
            if dictionary.get("Category")\
                else APIHelper.SKIP
        category_id =\
            dictionary.get("CategoryId")\
            if dictionary.get("CategoryId")\
                else APIHelper.SKIP
        subcategory =\
            dictionary.get("Subcategory")\
            if dictionary.get("Subcategory")\
                else APIHelper.SKIP
        subcategory_id =\
            dictionary.get("SubcategoryId")\
            if dictionary.get("SubcategoryId")\
                else APIHelper.SKIP
        available_for_add_on =\
            dictionary.get("AvailableForAddOn")\
            if "AvailableForAddOn" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(mtype,
                   default_time_length,
                   staff_time_length,
                   id,
                   name,
                   online_description,
                   num_deducted,
                   program_id,
                   category,
                   category_id,
                   subcategory,
                   subcategory_id,
                   available_for_add_on)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _default_time_length=(
            self.default_time_length
            if hasattr(self, "default_time_length")
            else None
        )
        _staff_time_length=(
            self.staff_time_length
            if hasattr(self, "staff_time_length")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _online_description=(
            self.online_description
            if hasattr(self, "online_description")
            else None
        )
        _num_deducted=(
            self.num_deducted
            if hasattr(self, "num_deducted")
            else None
        )
        _program_id=(
            self.program_id
            if hasattr(self, "program_id")
            else None
        )
        _category=(
            self.category
            if hasattr(self, "category")
            else None
        )
        _category_id=(
            self.category_id
            if hasattr(self, "category_id")
            else None
        )
        _subcategory=(
            self.subcategory
            if hasattr(self, "subcategory")
            else None
        )
        _subcategory_id=(
            self.subcategory_id
            if hasattr(self, "subcategory_id")
            else None
        )
        _available_for_add_on=(
            self.available_for_add_on
            if hasattr(self, "available_for_add_on")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"mtype={_mtype!r}, "
            f"default_time_length={_default_time_length!r}, "
            f"staff_time_length={_staff_time_length!r}, "
            f"id={_id!r}, "
            f"name={_name!r}, "
            f"online_description={_online_description!r}, "
            f"num_deducted={_num_deducted!r}, "
            f"program_id={_program_id!r}, "
            f"category={_category!r}, "
            f"category_id={_category_id!r}, "
            f"subcategory={_subcategory!r}, "
            f"subcategory_id={_subcategory_id!r}, "
            f"available_for_add_on={_available_for_add_on!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _default_time_length=(
            self.default_time_length
            if hasattr(self, "default_time_length")
            else None
        )
        _staff_time_length=(
            self.staff_time_length
            if hasattr(self, "staff_time_length")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _online_description=(
            self.online_description
            if hasattr(self, "online_description")
            else None
        )
        _num_deducted=(
            self.num_deducted
            if hasattr(self, "num_deducted")
            else None
        )
        _program_id=(
            self.program_id
            if hasattr(self, "program_id")
            else None
        )
        _category=(
            self.category
            if hasattr(self, "category")
            else None
        )
        _category_id=(
            self.category_id
            if hasattr(self, "category_id")
            else None
        )
        _subcategory=(
            self.subcategory
            if hasattr(self, "subcategory")
            else None
        )
        _subcategory_id=(
            self.subcategory_id
            if hasattr(self, "subcategory_id")
            else None
        )
        _available_for_add_on=(
            self.available_for_add_on
            if hasattr(self, "available_for_add_on")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"mtype={_mtype!s}, "
            f"default_time_length={_default_time_length!s}, "
            f"staff_time_length={_staff_time_length!s}, "
            f"id={_id!s}, "
            f"name={_name!s}, "
            f"online_description={_online_description!s}, "
            f"num_deducted={_num_deducted!s}, "
            f"program_id={_program_id!s}, "
            f"category={_category!s}, "
            f"category_id={_category_id!s}, "
            f"subcategory={_subcategory!s}, "
            f"subcategory_id={_subcategory_id!s}, "
            f"available_for_add_on={_available_for_add_on!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class SalePayment(object):
    """Implementation of the 'SalePayment' model.

    Attributes:
        id (int): A unique identifier for this payment.
        amount (float): The total amount of sales that were made on the sale date,
            including all payment methods that were used and taxes that were
            collected.
        method (int): The method used to make this payment.
        mtype (str): The payment method type used for the client’s purchase.
        notes (str): Payment notes that are entered under the selected payment method
            in the Retail screen before completing the sale.
        transaction_id (int): The ID of transaction. Use this ID when calling the GET
            Transactions endpoint.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "amount": "Amount",
        "method": "Method",
        "mtype": "Type",
        "notes": "Notes",
        "transaction_id": "TransactionId",
    }

    _optionals = [
        "id",
        "amount",
        "method",
        "mtype",
        "notes",
        "transaction_id",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        amount=APIHelper.SKIP,
        method=APIHelper.SKIP,
        mtype=APIHelper.SKIP,
        notes=APIHelper.SKIP,
        transaction_id=APIHelper.SKIP):
        """Initialize a SalePayment instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if amount is not APIHelper.SKIP:
            self.amount = amount
        if method is not APIHelper.SKIP:
            self.method = method
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype
        if notes is not APIHelper.SKIP:
            self.notes = notes
        if transaction_id is not APIHelper.SKIP:
            self.transaction_id = transaction_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        amount =\
            dictionary.get("Amount")\
            if dictionary.get("Amount")\
                else APIHelper.SKIP
        method =\
            dictionary.get("Method")\
            if dictionary.get("Method")\
                else APIHelper.SKIP
        mtype =\
            dictionary.get("Type")\
            if dictionary.get("Type")\
                else APIHelper.SKIP
        notes =\
            dictionary.get("Notes")\
            if dictionary.get("Notes")\
                else APIHelper.SKIP
        transaction_id =\
            dictionary.get("TransactionId")\
            if dictionary.get("TransactionId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   amount,
                   method,
                   mtype,
                   notes,
                   transaction_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _amount=(
            self.amount
            if hasattr(self, "amount")
            else None
        )
        _method=(
            self.method
            if hasattr(self, "method")
            else None
        )
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _transaction_id=(
            self.transaction_id
            if hasattr(self, "transaction_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"amount={_amount!r}, "
            f"method={_method!r}, "
            f"mtype={_mtype!r}, "
            f"notes={_notes!r}, "
            f"transaction_id={_transaction_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _amount=(
            self.amount
            if hasattr(self, "amount")
            else None
        )
        _method=(
            self.method
            if hasattr(self, "method")
            else None
        )
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _transaction_id=(
            self.transaction_id
            if hasattr(self, "transaction_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"amount={_amount!s}, "
            f"method={_method!s}, "
            f"mtype={_mtype!s}, "
            f"notes={_notes!s}, "
            f"transaction_id={_transaction_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class Service(object):
    """Implementation of the 'Service' model.

    Attributes:
        price (float): The cost of the pricing option when sold at a physical
            location.
        online_price (float): The cost of the pricing option when sold online.
        tax_included (float): The amount of tax included in the price, if inclusive
            pricing is enabled.
        program_id (int): The ID of the program that this pricing option applies to.
        tax_rate (float): The tax rate applied to the pricing option. This field is
            populated only when you include a `LocationID` in the request.
        product_id (int): The unique ID of this pricing option. This is the
            `PurchasedItems[].Id` returned from GET Sales.
        id (str): The barcode ID of the pricing option. This is the
            `PurchasedItems[].BarcodeId` returned from GET Sales.
        name (str): The name of the pricing option.
        count (int): The initial count of usages available for the pricing option.
        sell_online (bool): When true, filters to the pricing options that can be
            sold online.  Default: *false*
        sale_in_contract_only (bool): When `true`, indicates that the pricing option
            is allowed to be purchased in a contract or package.  When `false`,
            indicates that the pricing option is not allowed to be purchased in a
            contract or package.
        mtype (str): The type of the pricing option, either Drop-in, Series, or
            Unlimited.
        expiration_type (str): The date the pricing option begins its activation,
            either the date of sale or the date the client first used it for a visit.
        expiration_unit (str): The unit, either days or months, of
            `ExpirationLength`, indicating how long the pricing option is active for.
        expiration_length (int): The number of days or months that the pricing option
            is active for.
        revenue_category (str): The revenue category of the pricing option.
        membership_id (int): The ID that this pricing option grants membership to.
        sell_at_location_ids (List[int]): The location IDs where this pricing option
            is sold.
        use_at_location_ids (List[int]): The location IDs where this pricing option
            may be used.
        priority (str): The priority of the pricing option, either High, Medium, or
            Low.
        is_intro_offer (bool): Indicates if this pricing option is an introductory
            offer.
        intro_offer_type (str): When `IsIntroOffer` is true, this indicates if this
            introductory offer may be purchased by new clients or new and existing
            clients.
        is_third_party_discount_pricing (bool): Indicates whether this pricing option
            is sold at discounted rates by third-party services, such as ClassPass.
        program (str): The name of the service category the pricing option belongs to.
        discontinued (bool): If the pricing option has been marked discontinued.
        restrict_to_membership_ids (List[int]): Restricted to members of these
            membership ids.
        apply_member_discounts_of_membership_ids (List[int]): Discounts applied of
            these membership ids.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "price": "Price",
        "online_price": "OnlinePrice",
        "tax_included": "TaxIncluded",
        "program_id": "ProgramId",
        "tax_rate": "TaxRate",
        "product_id": "ProductId",
        "id": "Id",
        "name": "Name",
        "count": "Count",
        "sell_online": "SellOnline",
        "sale_in_contract_only": "SaleInContractOnly",
        "mtype": "Type",
        "expiration_type": "ExpirationType",
        "expiration_unit": "ExpirationUnit",
        "expiration_length": "ExpirationLength",
        "revenue_category": "RevenueCategory",
        "membership_id": "MembershipId",
        "sell_at_location_ids": "SellAtLocationIds",
        "use_at_location_ids": "UseAtLocationIds",
        "priority": "Priority",
        "is_intro_offer": "IsIntroOffer",
        "intro_offer_type": "IntroOfferType",
        "is_third_party_discount_pricing": "IsThirdPartyDiscountPricing",
        "program": "Program",
        "discontinued": "Discontinued",
        "restrict_to_membership_ids": "RestrictToMembershipIds",
        "apply_member_discounts_of_membership_ids":
            "ApplyMemberDiscountsOfMembershipIds",
    }

    _optionals = [
        "price",
        "online_price",
        "tax_included",
        "program_id",
        "tax_rate",
        "product_id",
        "id",
        "name",
        "count",
        "sell_online",
        "sale_in_contract_only",
        "mtype",
        "expiration_type",
        "expiration_unit",
        "expiration_length",
        "revenue_category",
        "membership_id",
        "sell_at_location_ids",
        "use_at_location_ids",
        "priority",
        "is_intro_offer",
        "intro_offer_type",
        "is_third_party_discount_pricing",
        "program",
        "discontinued",
        "restrict_to_membership_ids",
        "apply_member_discounts_of_membership_ids",
    ]

    def __init__(
        self,
        price=APIHelper.SKIP,
        online_price=APIHelper.SKIP,
        tax_included=APIHelper.SKIP,
        program_id=APIHelper.SKIP,
        tax_rate=APIHelper.SKIP,
        product_id=APIHelper.SKIP,
        id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        count=APIHelper.SKIP,
        sell_online=APIHelper.SKIP,
        sale_in_contract_only=APIHelper.SKIP,
        mtype=APIHelper.SKIP,
        expiration_type=APIHelper.SKIP,
        expiration_unit=APIHelper.SKIP,
        expiration_length=APIHelper.SKIP,
        revenue_category=APIHelper.SKIP,
        membership_id=APIHelper.SKIP,
        sell_at_location_ids=APIHelper.SKIP,
        use_at_location_ids=APIHelper.SKIP,
        priority=APIHelper.SKIP,
        is_intro_offer=APIHelper.SKIP,
        intro_offer_type=APIHelper.SKIP,
        is_third_party_discount_pricing=APIHelper.SKIP,
        program=APIHelper.SKIP,
        discontinued=APIHelper.SKIP,
        restrict_to_membership_ids=APIHelper.SKIP,
        apply_member_discounts_of_membership_ids=APIHelper.SKIP):
        """Initialize a Service instance."""
        # Initialize members of the class
        if price is not APIHelper.SKIP:
            self.price = price
        if online_price is not APIHelper.SKIP:
            self.online_price = online_price
        if tax_included is not APIHelper.SKIP:
            self.tax_included = tax_included
        if program_id is not APIHelper.SKIP:
            self.program_id = program_id
        if tax_rate is not APIHelper.SKIP:
            self.tax_rate = tax_rate
        if product_id is not APIHelper.SKIP:
            self.product_id = product_id
        if id is not APIHelper.SKIP:
            self.id = id
        if name is not APIHelper.SKIP:
            self.name = name
        if count is not APIHelper.SKIP:
            self.count = count
        if sell_online is not APIHelper.SKIP:
            self.sell_online = sell_online
        if sale_in_contract_only is not APIHelper.SKIP:
            self.sale_in_contract_only = sale_in_contract_only
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype
        if expiration_type is not APIHelper.SKIP:
            self.expiration_type = expiration_type
        if expiration_unit is not APIHelper.SKIP:
            self.expiration_unit = expiration_unit
        if expiration_length is not APIHelper.SKIP:
            self.expiration_length = expiration_length
        if revenue_category is not APIHelper.SKIP:
            self.revenue_category = revenue_category
        if membership_id is not APIHelper.SKIP:
            self.membership_id = membership_id
        if sell_at_location_ids is not APIHelper.SKIP:
            self.sell_at_location_ids = sell_at_location_ids
        if use_at_location_ids is not APIHelper.SKIP:
            self.use_at_location_ids = use_at_location_ids
        if priority is not APIHelper.SKIP:
            self.priority = priority
        if is_intro_offer is not APIHelper.SKIP:
            self.is_intro_offer = is_intro_offer
        if intro_offer_type is not APIHelper.SKIP:
            self.intro_offer_type = intro_offer_type
        if is_third_party_discount_pricing is not APIHelper.SKIP:
            self.is_third_party_discount_pricing = is_third_party_discount_pricing
        if program is not APIHelper.SKIP:
            self.program = program
        if discontinued is not APIHelper.SKIP:
            self.discontinued = discontinued
        if restrict_to_membership_ids is not APIHelper.SKIP:
            self.restrict_to_membership_ids = restrict_to_membership_ids
        if apply_member_discounts_of_membership_ids is not APIHelper.SKIP:
            self.apply_member_discounts_of_membership_ids =\
                 apply_member_discounts_of_membership_ids

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        price =\
            dictionary.get("Price")\
            if dictionary.get("Price")\
                else APIHelper.SKIP
        online_price =\
            dictionary.get("OnlinePrice")\
            if dictionary.get("OnlinePrice")\
                else APIHelper.SKIP
        tax_included =\
            dictionary.get("TaxIncluded")\
            if dictionary.get("TaxIncluded")\
                else APIHelper.SKIP
        program_id =\
            dictionary.get("ProgramId")\
            if dictionary.get("ProgramId")\
                else APIHelper.SKIP
        tax_rate =\
            dictionary.get("TaxRate")\
            if dictionary.get("TaxRate")\
                else APIHelper.SKIP
        product_id =\
            dictionary.get("ProductId")\
            if dictionary.get("ProductId")\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        count =\
            dictionary.get("Count")\
            if dictionary.get("Count")\
                else APIHelper.SKIP
        sell_online =\
            dictionary.get("SellOnline")\
            if "SellOnline" in dictionary.keys()\
                else APIHelper.SKIP
        sale_in_contract_only =\
            dictionary.get("SaleInContractOnly")\
            if "SaleInContractOnly" in dictionary.keys()\
                else APIHelper.SKIP
        mtype =\
            dictionary.get("Type")\
            if dictionary.get("Type")\
                else APIHelper.SKIP
        expiration_type =\
            dictionary.get("ExpirationType")\
            if dictionary.get("ExpirationType")\
                else APIHelper.SKIP
        expiration_unit =\
            dictionary.get("ExpirationUnit")\
            if dictionary.get("ExpirationUnit")\
                else APIHelper.SKIP
        expiration_length =\
            dictionary.get("ExpirationLength")\
            if dictionary.get("ExpirationLength")\
                else APIHelper.SKIP
        revenue_category =\
            dictionary.get("RevenueCategory")\
            if dictionary.get("RevenueCategory")\
                else APIHelper.SKIP
        membership_id =\
            dictionary.get("MembershipId")\
            if dictionary.get("MembershipId")\
                else APIHelper.SKIP
        sell_at_location_ids =\
            dictionary.get("SellAtLocationIds")\
            if dictionary.get("SellAtLocationIds")\
                else APIHelper.SKIP
        use_at_location_ids =\
            dictionary.get("UseAtLocationIds")\
            if dictionary.get("UseAtLocationIds")\
                else APIHelper.SKIP
        priority =\
            dictionary.get("Priority")\
            if dictionary.get("Priority")\
                else APIHelper.SKIP
        is_intro_offer =\
            dictionary.get("IsIntroOffer")\
            if "IsIntroOffer" in dictionary.keys()\
                else APIHelper.SKIP
        intro_offer_type =\
            dictionary.get("IntroOfferType")\
            if dictionary.get("IntroOfferType")\
                else APIHelper.SKIP
        is_third_party_discount_pricing =\
            dictionary.get("IsThirdPartyDiscountPricing")\
            if "IsThirdPartyDiscountPricing" in dictionary.keys()\
                else APIHelper.SKIP
        program =\
            dictionary.get("Program")\
            if dictionary.get("Program")\
                else APIHelper.SKIP
        discontinued =\
            dictionary.get("Discontinued")\
            if "Discontinued" in dictionary.keys()\
                else APIHelper.SKIP
        restrict_to_membership_ids =\
            dictionary.get("RestrictToMembershipIds")\
            if dictionary.get("RestrictToMembershipIds")\
                else APIHelper.SKIP
        apply_member_discounts_of_membership_ids =\
            dictionary.get("ApplyMemberDiscountsOfMembershipIds")\
            if dictionary.get("ApplyMemberDiscountsOfMembershipIds")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(price,
                   online_price,
                   tax_included,
                   program_id,
                   tax_rate,
                   product_id,
                   id,
                   name,
                   count,
                   sell_online,
                   sale_in_contract_only,
                   mtype,
                   expiration_type,
                   expiration_unit,
                   expiration_length,
                   revenue_category,
                   membership_id,
                   sell_at_location_ids,
                   use_at_location_ids,
                   priority,
                   is_intro_offer,
                   intro_offer_type,
                   is_third_party_discount_pricing,
                   program,
                   discontinued,
                   restrict_to_membership_ids,
                   apply_member_discounts_of_membership_ids)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _price=(
            self.price
            if hasattr(self, "price")
            else None
        )
        _online_price=(
            self.online_price
            if hasattr(self, "online_price")
            else None
        )
        _tax_included=(
            self.tax_included
            if hasattr(self, "tax_included")
            else None
        )
        _program_id=(
            self.program_id
            if hasattr(self, "program_id")
            else None
        )
        _tax_rate=(
            self.tax_rate
            if hasattr(self, "tax_rate")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _count=(
            self.count
            if hasattr(self, "count")
            else None
        )
        _sell_online=(
            self.sell_online
            if hasattr(self, "sell_online")
            else None
        )
        _sale_in_contract_only=(
            self.sale_in_contract_only
            if hasattr(self, "sale_in_contract_only")
            else None
        )
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _expiration_type=(
            self.expiration_type
            if hasattr(self, "expiration_type")
            else None
        )
        _expiration_unit=(
            self.expiration_unit
            if hasattr(self, "expiration_unit")
            else None
        )
        _expiration_length=(
            self.expiration_length
            if hasattr(self, "expiration_length")
            else None
        )
        _revenue_category=(
            self.revenue_category
            if hasattr(self, "revenue_category")
            else None
        )
        _membership_id=(
            self.membership_id
            if hasattr(self, "membership_id")
            else None
        )
        _sell_at_location_ids=(
            self.sell_at_location_ids
            if hasattr(self, "sell_at_location_ids")
            else None
        )
        _use_at_location_ids=(
            self.use_at_location_ids
            if hasattr(self, "use_at_location_ids")
            else None
        )
        _priority=(
            self.priority
            if hasattr(self, "priority")
            else None
        )
        _is_intro_offer=(
            self.is_intro_offer
            if hasattr(self, "is_intro_offer")
            else None
        )
        _intro_offer_type=(
            self.intro_offer_type
            if hasattr(self, "intro_offer_type")
            else None
        )
        _is_third_party_discount_pricing=(
            self.is_third_party_discount_pricing
            if hasattr(self, "is_third_party_discount_pricing")
            else None
        )
        _program=(
            self.program
            if hasattr(self, "program")
            else None
        )
        _discontinued=(
            self.discontinued
            if hasattr(self, "discontinued")
            else None
        )
        _restrict_to_membership_ids=(
            self.restrict_to_membership_ids
            if hasattr(self, "restrict_to_membership_ids")
            else None
        )
        _apply_member_discounts_of_membership_ids=(
            self.apply_member_discounts_of_membership_ids
            if hasattr(self, "apply_member_discounts_of_membership_ids")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"price={_price!r}, "
            f"online_price={_online_price!r}, "
            f"tax_included={_tax_included!r}, "
            f"program_id={_program_id!r}, "
            f"tax_rate={_tax_rate!r}, "
            f"product_id={_product_id!r}, "
            f"id={_id!r}, "
            f"name={_name!r}, "
            f"count={_count!r}, "
            f"sell_online={_sell_online!r}, "
            f"sale_in_contract_only={_sale_in_contract_only!r}, "
            f"mtype={_mtype!r}, "
            f"expiration_type={_expiration_type!r}, "
            f"expiration_unit={_expiration_unit!r}, "
            f"expiration_length={_expiration_length!r}, "
            f"revenue_category={_revenue_category!r}, "
            f"membership_id={_membership_id!r}, "
            f"sell_at_location_ids={_sell_at_location_ids!r}, "
            f"use_at_location_ids={_use_at_location_ids!r}, "
            f"priority={_priority!r}, "
            f"is_intro_offer={_is_intro_offer!r}, "
            f"intro_offer_type={_intro_offer_type!r}, "
            f"is_third_party_discount_pricing={_is_third_party_discount_pricing!r}, "
            f"program={_program!r}, "
            f"discontinued={_discontinued!r}, "
            f"restrict_to_membership_ids={_restrict_to_membership_ids!r}, "
            f"apply_member_discounts_of_membership_ids={_apply_member_discounts_of_membership_ids!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _price=(
            self.price
            if hasattr(self, "price")
            else None
        )
        _online_price=(
            self.online_price
            if hasattr(self, "online_price")
            else None
        )
        _tax_included=(
            self.tax_included
            if hasattr(self, "tax_included")
            else None
        )
        _program_id=(
            self.program_id
            if hasattr(self, "program_id")
            else None
        )
        _tax_rate=(
            self.tax_rate
            if hasattr(self, "tax_rate")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _count=(
            self.count
            if hasattr(self, "count")
            else None
        )
        _sell_online=(
            self.sell_online
            if hasattr(self, "sell_online")
            else None
        )
        _sale_in_contract_only=(
            self.sale_in_contract_only
            if hasattr(self, "sale_in_contract_only")
            else None
        )
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _expiration_type=(
            self.expiration_type
            if hasattr(self, "expiration_type")
            else None
        )
        _expiration_unit=(
            self.expiration_unit
            if hasattr(self, "expiration_unit")
            else None
        )
        _expiration_length=(
            self.expiration_length
            if hasattr(self, "expiration_length")
            else None
        )
        _revenue_category=(
            self.revenue_category
            if hasattr(self, "revenue_category")
            else None
        )
        _membership_id=(
            self.membership_id
            if hasattr(self, "membership_id")
            else None
        )
        _sell_at_location_ids=(
            self.sell_at_location_ids
            if hasattr(self, "sell_at_location_ids")
            else None
        )
        _use_at_location_ids=(
            self.use_at_location_ids
            if hasattr(self, "use_at_location_ids")
            else None
        )
        _priority=(
            self.priority
            if hasattr(self, "priority")
            else None
        )
        _is_intro_offer=(
            self.is_intro_offer
            if hasattr(self, "is_intro_offer")
            else None
        )
        _intro_offer_type=(
            self.intro_offer_type
            if hasattr(self, "intro_offer_type")
            else None
        )
        _is_third_party_discount_pricing=(
            self.is_third_party_discount_pricing
            if hasattr(self, "is_third_party_discount_pricing")
            else None
        )
        _program=(
            self.program
            if hasattr(self, "program")
            else None
        )
        _discontinued=(
            self.discontinued
            if hasattr(self, "discontinued")
            else None
        )
        _restrict_to_membership_ids=(
            self.restrict_to_membership_ids
            if hasattr(self, "restrict_to_membership_ids")
            else None
        )
        _apply_member_discounts_of_membership_ids=(
            self.apply_member_discounts_of_membership_ids
            if hasattr(self, "apply_member_discounts_of_membership_ids")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"price={_price!s}, "
            f"online_price={_online_price!s}, "
            f"tax_included={_tax_included!s}, "
            f"program_id={_program_id!s}, "
            f"tax_rate={_tax_rate!s}, "
            f"product_id={_product_id!s}, "
            f"id={_id!s}, "
            f"name={_name!s}, "
            f"count={_count!s}, "
            f"sell_online={_sell_online!s}, "
            f"sale_in_contract_only={_sale_in_contract_only!s}, "
            f"mtype={_mtype!s}, "
            f"expiration_type={_expiration_type!s}, "
            f"expiration_unit={_expiration_unit!s}, "
            f"expiration_length={_expiration_length!s}, "
            f"revenue_category={_revenue_category!s}, "
            f"membership_id={_membership_id!s}, "
            f"sell_at_location_ids={_sell_at_location_ids!s}, "
            f"use_at_location_ids={_use_at_location_ids!s}, "
            f"priority={_priority!s}, "
            f"is_intro_offer={_is_intro_offer!s}, "
            f"intro_offer_type={_intro_offer_type!s}, "
            f"is_third_party_discount_pricing={_is_third_party_discount_pricing!s}, "
            f"program={_program!s}, "
            f"discontinued={_discontinued!s}, "
            f"restrict_to_membership_ids={_restrict_to_membership_ids!s}, "
            f"apply_member_discounts_of_membership_ids={_apply_member_discounts_of_membership_ids!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.upcoming_autopay_event import (
    UpcomingAutopayEvent,
)


class ClientContract(object):
    """Implementation of the 'ClientContract' model.

    A client contract.

    Attributes:
        agreement_date (datetime): The date on which the contract was signed.
        autopay_status (AutopayStatusEnum): The status of the client’s autopay.
        auto_renewing (bool): Determines if the contract is auto-renewing.
        first_auto_pay (float): The amount of the first autopay transaction.
        last_auto_pay (float): The amount of the last autopay transaction.
        normal_auto_pay (float): The amount of the normal recurring autopay
            transaction.
        is_month_to_month (bool): Indicates if the contract renews on a
            month-to-month basis.
        auto_renew_client_contract_id (int): The ID of the contract that this one
            auto-renews from.
        contract_text (str): The full text of the contract.
        contract_auto_renewed (bool): Indicates whether the contract was auto-renewed
            from a previous one.
        contract_name (str): The name of the contract.
        end_date (datetime): The date that the contract expires.
        id (int): The unique ID of the sale of the contract. Each time a contract is
            sold, this ID increases sequentially.
        origination_location_id (int): The ID of the location where the contract was
            issued.
        start_date (datetime): The date that the contract became active.
        site_id (int): The ID of the site where the contract was issued.
        upcoming_autopay_events (List[UpcomingAutopayEvent]): Contains details of the
            autopay events.
        contract_id (int): The ID of the contract.
        termination_date (datetime): The date that the contract was terminated.
        minimum_commitment_value (int): Minimum commitment value.
        minimum_commitment_unit (MinimumCommitmentUnitEnum): Minimum commitment unit
            type.
        minimum_commitment_end_date (datetime): The earliest date a contract
            termination can take effect if a minimum commitment applies.  This
            represents the last day the client is obligated to remain on the
            contract.  Returned even if the commitment has already been fulfilled.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "agreement_date": "AgreementDate",
        "autopay_status": "AutopayStatus",
        "auto_renewing": "AutoRenewing",
        "first_auto_pay": "FirstAutoPay",
        "last_auto_pay": "LastAutoPay",
        "normal_auto_pay": "NormalAutoPay",
        "is_month_to_month": "IsMonthToMonth",
        "auto_renew_client_contract_id": "AutoRenewClientContractID",
        "contract_text": "ContractText",
        "contract_auto_renewed": "ContractAutoRenewed",
        "contract_name": "ContractName",
        "end_date": "EndDate",
        "id": "Id",
        "origination_location_id": "OriginationLocationId",
        "start_date": "StartDate",
        "site_id": "SiteId",
        "upcoming_autopay_events": "UpcomingAutopayEvents",
        "contract_id": "ContractID",
        "termination_date": "TerminationDate",
        "minimum_commitment_value": "MinimumCommitmentValue",
        "minimum_commitment_unit": "MinimumCommitmentUnit",
        "minimum_commitment_end_date": "MinimumCommitmentEndDate",
    }

    _optionals = [
        "agreement_date",
        "autopay_status",
        "auto_renewing",
        "first_auto_pay",
        "last_auto_pay",
        "normal_auto_pay",
        "is_month_to_month",
        "auto_renew_client_contract_id",
        "contract_text",
        "contract_auto_renewed",
        "contract_name",
        "end_date",
        "id",
        "origination_location_id",
        "start_date",
        "site_id",
        "upcoming_autopay_events",
        "contract_id",
        "termination_date",
        "minimum_commitment_value",
        "minimum_commitment_unit",
        "minimum_commitment_end_date",
    ]

    def __init__(
        self,
        agreement_date=APIHelper.SKIP,
        autopay_status=APIHelper.SKIP,
        auto_renewing=APIHelper.SKIP,
        first_auto_pay=APIHelper.SKIP,
        last_auto_pay=APIHelper.SKIP,
        normal_auto_pay=APIHelper.SKIP,
        is_month_to_month=APIHelper.SKIP,
        auto_renew_client_contract_id=APIHelper.SKIP,
        contract_text=APIHelper.SKIP,
        contract_auto_renewed=APIHelper.SKIP,
        contract_name=APIHelper.SKIP,
        end_date=APIHelper.SKIP,
        id=APIHelper.SKIP,
        origination_location_id=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        site_id=APIHelper.SKIP,
        upcoming_autopay_events=APIHelper.SKIP,
        contract_id=APIHelper.SKIP,
        termination_date=APIHelper.SKIP,
        minimum_commitment_value=APIHelper.SKIP,
        minimum_commitment_unit=APIHelper.SKIP,
        minimum_commitment_end_date=APIHelper.SKIP):
        """Initialize a ClientContract instance."""
        # Initialize members of the class
        if agreement_date is not APIHelper.SKIP:
            self.agreement_date =\
                 APIHelper.apply_datetime_converter(
                agreement_date, APIHelper.RFC3339DateTime)\
                 if agreement_date else None
        if autopay_status is not APIHelper.SKIP:
            self.autopay_status = autopay_status
        if auto_renewing is not APIHelper.SKIP:
            self.auto_renewing = auto_renewing
        if first_auto_pay is not APIHelper.SKIP:
            self.first_auto_pay = first_auto_pay
        if last_auto_pay is not APIHelper.SKIP:
            self.last_auto_pay = last_auto_pay
        if normal_auto_pay is not APIHelper.SKIP:
            self.normal_auto_pay = normal_auto_pay
        if is_month_to_month is not APIHelper.SKIP:
            self.is_month_to_month = is_month_to_month
        if auto_renew_client_contract_id is not APIHelper.SKIP:
            self.auto_renew_client_contract_id = auto_renew_client_contract_id
        if contract_text is not APIHelper.SKIP:
            self.contract_text = contract_text
        if contract_auto_renewed is not APIHelper.SKIP:
            self.contract_auto_renewed = contract_auto_renewed
        if contract_name is not APIHelper.SKIP:
            self.contract_name = contract_name
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None
        if id is not APIHelper.SKIP:
            self.id = id
        if origination_location_id is not APIHelper.SKIP:
            self.origination_location_id = origination_location_id
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id
        if upcoming_autopay_events is not APIHelper.SKIP:
            self.upcoming_autopay_events = upcoming_autopay_events
        if contract_id is not APIHelper.SKIP:
            self.contract_id = contract_id
        if termination_date is not APIHelper.SKIP:
            self.termination_date =\
                 APIHelper.apply_datetime_converter(
                termination_date, APIHelper.RFC3339DateTime)\
                 if termination_date else None
        if minimum_commitment_value is not APIHelper.SKIP:
            self.minimum_commitment_value = minimum_commitment_value
        if minimum_commitment_unit is not APIHelper.SKIP:
            self.minimum_commitment_unit = minimum_commitment_unit
        if minimum_commitment_end_date is not APIHelper.SKIP:
            self.minimum_commitment_end_date =\
                 APIHelper.apply_datetime_converter(
                minimum_commitment_end_date, APIHelper.RFC3339DateTime)\
                 if minimum_commitment_end_date else None

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        agreement_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("AgreementDate")).datetime\
            if dictionary.get("AgreementDate") else APIHelper.SKIP
        autopay_status =\
            dictionary.get("AutopayStatus")\
            if dictionary.get("AutopayStatus")\
                else APIHelper.SKIP
        auto_renewing =\
            dictionary.get("AutoRenewing")\
            if "AutoRenewing" in dictionary.keys()\
                else APIHelper.SKIP
        first_auto_pay =\
            dictionary.get("FirstAutoPay")\
            if dictionary.get("FirstAutoPay")\
                else APIHelper.SKIP
        last_auto_pay =\
            dictionary.get("LastAutoPay")\
            if dictionary.get("LastAutoPay")\
                else APIHelper.SKIP
        normal_auto_pay =\
            dictionary.get("NormalAutoPay")\
            if dictionary.get("NormalAutoPay")\
                else APIHelper.SKIP
        is_month_to_month =\
            dictionary.get("IsMonthToMonth")\
            if "IsMonthToMonth" in dictionary.keys()\
                else APIHelper.SKIP
        auto_renew_client_contract_id =\
            dictionary.get("AutoRenewClientContractID")\
            if dictionary.get("AutoRenewClientContractID")\
                else APIHelper.SKIP
        contract_text =\
            dictionary.get("ContractText")\
            if dictionary.get("ContractText")\
                else APIHelper.SKIP
        contract_auto_renewed =\
            dictionary.get("ContractAutoRenewed")\
            if "ContractAutoRenewed" in dictionary.keys()\
                else APIHelper.SKIP
        contract_name =\
            dictionary.get("ContractName")\
            if dictionary.get("ContractName")\
                else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        origination_location_id =\
            dictionary.get("OriginationLocationId")\
            if dictionary.get("OriginationLocationId")\
                else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        site_id =\
            dictionary.get("SiteId")\
            if dictionary.get("SiteId")\
                else APIHelper.SKIP
        upcoming_autopay_events = None
        if dictionary.get("UpcomingAutopayEvents") is not None:
            upcoming_autopay_events = [
                UpcomingAutopayEvent.from_dictionary(x)
                    for x in dictionary.get("UpcomingAutopayEvents")
            ]
        else:
            upcoming_autopay_events = APIHelper.SKIP
        contract_id =\
            dictionary.get("ContractID")\
            if dictionary.get("ContractID")\
                else APIHelper.SKIP
        termination_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("TerminationDate")).datetime\
            if dictionary.get("TerminationDate") else APIHelper.SKIP
        minimum_commitment_value =\
            dictionary.get("MinimumCommitmentValue")\
            if dictionary.get("MinimumCommitmentValue")\
                else APIHelper.SKIP
        minimum_commitment_unit =\
            dictionary.get("MinimumCommitmentUnit")\
            if dictionary.get("MinimumCommitmentUnit")\
                else APIHelper.SKIP
        minimum_commitment_end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("MinimumCommitmentEndDate")).datetime\
            if dictionary.get("MinimumCommitmentEndDate") else APIHelper.SKIP

        # Return an object of this model
        return cls(agreement_date,
                   autopay_status,
                   auto_renewing,
                   first_auto_pay,
                   last_auto_pay,
                   normal_auto_pay,
                   is_month_to_month,
                   auto_renew_client_contract_id,
                   contract_text,
                   contract_auto_renewed,
                   contract_name,
                   end_date,
                   id,
                   origination_location_id,
                   start_date,
                   site_id,
                   upcoming_autopay_events,
                   contract_id,
                   termination_date,
                   minimum_commitment_value,
                   minimum_commitment_unit,
                   minimum_commitment_end_date)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _agreement_date=(
            self.agreement_date
            if hasattr(self, "agreement_date")
            else None
        )
        _autopay_status=(
            self.autopay_status
            if hasattr(self, "autopay_status")
            else None
        )
        _auto_renewing=(
            self.auto_renewing
            if hasattr(self, "auto_renewing")
            else None
        )
        _first_auto_pay=(
            self.first_auto_pay
            if hasattr(self, "first_auto_pay")
            else None
        )
        _last_auto_pay=(
            self.last_auto_pay
            if hasattr(self, "last_auto_pay")
            else None
        )
        _normal_auto_pay=(
            self.normal_auto_pay
            if hasattr(self, "normal_auto_pay")
            else None
        )
        _is_month_to_month=(
            self.is_month_to_month
            if hasattr(self, "is_month_to_month")
            else None
        )
        _auto_renew_client_contract_id=(
            self.auto_renew_client_contract_id
            if hasattr(self, "auto_renew_client_contract_id")
            else None
        )
        _contract_text=(
            self.contract_text
            if hasattr(self, "contract_text")
            else None
        )
        _contract_auto_renewed=(
            self.contract_auto_renewed
            if hasattr(self, "contract_auto_renewed")
            else None
        )
        _contract_name=(
            self.contract_name
            if hasattr(self, "contract_name")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _origination_location_id=(
            self.origination_location_id
            if hasattr(self, "origination_location_id")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _upcoming_autopay_events=(
            self.upcoming_autopay_events
            if hasattr(self, "upcoming_autopay_events")
            else None
        )
        _contract_id=(
            self.contract_id
            if hasattr(self, "contract_id")
            else None
        )
        _termination_date=(
            self.termination_date
            if hasattr(self, "termination_date")
            else None
        )
        _minimum_commitment_value=(
            self.minimum_commitment_value
            if hasattr(self, "minimum_commitment_value")
            else None
        )
        _minimum_commitment_unit=(
            self.minimum_commitment_unit
            if hasattr(self, "minimum_commitment_unit")
            else None
        )
        _minimum_commitment_end_date=(
            self.minimum_commitment_end_date
            if hasattr(self, "minimum_commitment_end_date")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"agreement_date={_agreement_date!r}, "
            f"autopay_status={_autopay_status!r}, "
            f"auto_renewing={_auto_renewing!r}, "
            f"first_auto_pay={_first_auto_pay!r}, "
            f"last_auto_pay={_last_auto_pay!r}, "
            f"normal_auto_pay={_normal_auto_pay!r}, "
            f"is_month_to_month={_is_month_to_month!r}, "
            f"auto_renew_client_contract_id={_auto_renew_client_contract_id!r}, "
            f"contract_text={_contract_text!r}, "
            f"contract_auto_renewed={_contract_auto_renewed!r}, "
            f"contract_name={_contract_name!r}, "
            f"end_date={_end_date!r}, "
            f"id={_id!r}, "
            f"origination_location_id={_origination_location_id!r}, "
            f"start_date={_start_date!r}, "
            f"site_id={_site_id!r}, "
            f"upcoming_autopay_events={_upcoming_autopay_events!r}, "
            f"contract_id={_contract_id!r}, "
            f"termination_date={_termination_date!r}, "
            f"minimum_commitment_value={_minimum_commitment_value!r}, "
            f"minimum_commitment_unit={_minimum_commitment_unit!r}, "
            f"minimum_commitment_end_date={_minimum_commitment_end_date!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _agreement_date=(
            self.agreement_date
            if hasattr(self, "agreement_date")
            else None
        )
        _autopay_status=(
            self.autopay_status
            if hasattr(self, "autopay_status")
            else None
        )
        _auto_renewing=(
            self.auto_renewing
            if hasattr(self, "auto_renewing")
            else None
        )
        _first_auto_pay=(
            self.first_auto_pay
            if hasattr(self, "first_auto_pay")
            else None
        )
        _last_auto_pay=(
            self.last_auto_pay
            if hasattr(self, "last_auto_pay")
            else None
        )
        _normal_auto_pay=(
            self.normal_auto_pay
            if hasattr(self, "normal_auto_pay")
            else None
        )
        _is_month_to_month=(
            self.is_month_to_month
            if hasattr(self, "is_month_to_month")
            else None
        )
        _auto_renew_client_contract_id=(
            self.auto_renew_client_contract_id
            if hasattr(self, "auto_renew_client_contract_id")
            else None
        )
        _contract_text=(
            self.contract_text
            if hasattr(self, "contract_text")
            else None
        )
        _contract_auto_renewed=(
            self.contract_auto_renewed
            if hasattr(self, "contract_auto_renewed")
            else None
        )
        _contract_name=(
            self.contract_name
            if hasattr(self, "contract_name")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _origination_location_id=(
            self.origination_location_id
            if hasattr(self, "origination_location_id")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _upcoming_autopay_events=(
            self.upcoming_autopay_events
            if hasattr(self, "upcoming_autopay_events")
            else None
        )
        _contract_id=(
            self.contract_id
            if hasattr(self, "contract_id")
            else None
        )
        _termination_date=(
            self.termination_date
            if hasattr(self, "termination_date")
            else None
        )
        _minimum_commitment_value=(
            self.minimum_commitment_value
            if hasattr(self, "minimum_commitment_value")
            else None
        )
        _minimum_commitment_unit=(
            self.minimum_commitment_unit
            if hasattr(self, "minimum_commitment_unit")
            else None
        )
        _minimum_commitment_end_date=(
            self.minimum_commitment_end_date
            if hasattr(self, "minimum_commitment_end_date")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"agreement_date={_agreement_date!s}, "
            f"autopay_status={_autopay_status!s}, "
            f"auto_renewing={_auto_renewing!s}, "
            f"first_auto_pay={_first_auto_pay!s}, "
            f"last_auto_pay={_last_auto_pay!s}, "
            f"normal_auto_pay={_normal_auto_pay!s}, "
            f"is_month_to_month={_is_month_to_month!s}, "
            f"auto_renew_client_contract_id={_auto_renew_client_contract_id!s}, "
            f"contract_text={_contract_text!s}, "
            f"contract_auto_renewed={_contract_auto_renewed!s}, "
            f"contract_name={_contract_name!s}, "
            f"end_date={_end_date!s}, "
            f"id={_id!s}, "
            f"origination_location_id={_origination_location_id!s}, "
            f"start_date={_start_date!s}, "
            f"site_id={_site_id!s}, "
            f"upcoming_autopay_events={_upcoming_autopay_events!s}, "
            f"contract_id={_contract_id!s}, "
            f"termination_date={_termination_date!s}, "
            f"minimum_commitment_value={_minimum_commitment_value!s}, "
            f"minimum_commitment_unit={_minimum_commitment_unit!s}, "
            f"minimum_commitment_end_date={_minimum_commitment_end_date!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

from apimatic_core.api_call import ApiCall
from apimatic_core.types.error_case import ErrorCase

from mindbodypublicapi.exceptions.api_exception import (
    APIException,
)


class BaseController(object):
    """All controllers inherit from this base class.

    Attributes:
        config (Configuration): The HttpClient which a specific controller
            instance will use. By default all the controller objects share
            the same HttpClient. A user can use his own custom HttpClient
            as well.
        http_call_back (HttpCallBack): An object which holds call back
            methods to be called before and after the execution of an HttpRequest.
        new_api_call_builder (APICall): Returns the API Call builder instance.

    """

    @staticmethod
    def user_agent():
        """Return UserAgent value."""
        return "APIMATIC 3.0"

    @staticmethod
    def user_agent_parameters():
        """Return UserAgentParameters value."""
        return {
        }

    @staticmethod
    def global_errors():
        """Return GlobalErrors value."""
        return {
            "default": ErrorCase()
                .error_message("HTTP response not OK.")
                .exception_type(APIException),
        }

    def __init__(self, config):
        """Initialize BaseController object."""
        self._config = config.get_http_client_configuration()
        self._http_call_back = self.config.http_callback
        self.api_call = ApiCall(config)

    @property
    def config(self):
        """Return Configuration object."""
        return self._config

    @property
    def http_call_back(self):
        """Return HttpCallBack object."""
        return self._http_call_back

    @property
    def new_api_call_builder(self):
        """Return New ApiCallBuilder object."""
        return self.api_call.new_builder



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class PurchaseContractResponseTotals(object):
    """Implementation of the 'PurchaseContractResponseTotals' model.

    Totals for the purchase

    Attributes:
        total (float): Total payment amount
        sub_total (float): Sub total. For VAT, sum of asking prices (include taxes,
            excludes discounts). For non vat, excludes taxes and discounts.
        discount (float): Discount
        tax (float): Tax

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "total": "Total",
        "sub_total": "SubTotal",
        "discount": "Discount",
        "tax": "Tax",
    }

    _optionals = [
        "total",
        "sub_total",
        "discount",
        "tax",
    ]

    def __init__(
        self,
        total=APIHelper.SKIP,
        sub_total=APIHelper.SKIP,
        discount=APIHelper.SKIP,
        tax=APIHelper.SKIP):
        """Initialize a PurchaseContractResponseTotals instance."""
        # Initialize members of the class
        if total is not APIHelper.SKIP:
            self.total = total
        if sub_total is not APIHelper.SKIP:
            self.sub_total = sub_total
        if discount is not APIHelper.SKIP:
            self.discount = discount
        if tax is not APIHelper.SKIP:
            self.tax = tax

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        total =\
            dictionary.get("Total")\
            if dictionary.get("Total")\
                else APIHelper.SKIP
        sub_total =\
            dictionary.get("SubTotal")\
            if dictionary.get("SubTotal")\
                else APIHelper.SKIP
        discount =\
            dictionary.get("Discount")\
            if dictionary.get("Discount")\
                else APIHelper.SKIP
        tax =\
            dictionary.get("Tax")\
            if dictionary.get("Tax")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(total,
                   sub_total,
                   discount,
                   tax)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _total=(
            self.total
            if hasattr(self, "total")
            else None
        )
        _sub_total=(
            self.sub_total
            if hasattr(self, "sub_total")
            else None
        )
        _discount=(
            self.discount
            if hasattr(self, "discount")
            else None
        )
        _tax=(
            self.tax
            if hasattr(self, "tax")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"total={_total!r}, "
            f"sub_total={_sub_total!r}, "
            f"discount={_discount!r}, "
            f"tax={_tax!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _total=(
            self.total
            if hasattr(self, "total")
            else None
        )
        _sub_total=(
            self.sub_total
            if hasattr(self, "sub_total")
            else None
        )
        _discount=(
            self.discount
            if hasattr(self, "discount")
            else None
        )
        _tax=(
            self.tax
            if hasattr(self, "tax")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"total={_total!s}, "
            f"sub_total={_sub_total!s}, "
            f"discount={_discount!s}, "
            f"tax={_tax!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetStaffRequest(object):
    """Implementation of the 'GetStaffRequest' model.

    Attributes:
        staff_ids (List[int]): A list of the requested staff IDs.
        filters (List[str]): Filters to apply to the search. Possible values are:  *
            StaffViewable  * AppointmentInstructor  * ClassInstructor  * Male  *
            Female
        session_type_id (int): Return only staff members that are available for the
            specified session type. You must supply a valid `StartDateTime` and
            `LocationID` to use this parameter.
        start_date_time (datetime): Return only staff members that are available at
            the specified date and time. You must supply a valid `SessionTypeID` and
            `LocationID` to use this parameter.
        location_id (int): Return only staff members that are available at the
            specified location. You must supply a valid `SessionTypeID` and
            `StartDateTime` to use this parameter.
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "staff_ids": "StaffIds",
        "filters": "Filters",
        "session_type_id": "SessionTypeId",
        "start_date_time": "StartDateTime",
        "location_id": "LocationId",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "staff_ids",
        "filters",
        "session_type_id",
        "start_date_time",
        "location_id",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        staff_ids=APIHelper.SKIP,
        filters=APIHelper.SKIP,
        session_type_id=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetStaffRequest instance."""
        # Initialize members of the class
        if staff_ids is not APIHelper.SKIP:
            self.staff_ids = staff_ids
        if filters is not APIHelper.SKIP:
            self.filters = filters
        if session_type_id is not APIHelper.SKIP:
            self.session_type_id = session_type_id
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        staff_ids =\
            dictionary.get("StaffIds")\
            if dictionary.get("StaffIds")\
                else APIHelper.SKIP
        filters =\
            dictionary.get("Filters")\
            if dictionary.get("Filters")\
                else APIHelper.SKIP
        session_type_id =\
            dictionary.get("SessionTypeId")\
            if dictionary.get("SessionTypeId")\
                else APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(staff_ids,
                   filters,
                   session_type_id,
                   start_date_time,
                   location_id,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _staff_ids=(
            self.staff_ids
            if hasattr(self, "staff_ids")
            else None
        )
        _filters=(
            self.filters
            if hasattr(self, "filters")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_ids={_staff_ids!r}, "
            f"filters={_filters!r}, "
            f"session_type_id={_session_type_id!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"location_id={_location_id!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _staff_ids=(
            self.staff_ids
            if hasattr(self, "staff_ids")
            else None
        )
        _filters=(
            self.filters
            if hasattr(self, "filters")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_ids={_staff_ids!s}, "
            f"filters={_filters!s}, "
            f"session_type_id={_session_type_id!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"location_id={_location_id!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""
mindbodypublicapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from apimatic_core.types.file_wrapper import FileWrapper as CoreFileWrapper


class FileWrapper(CoreFileWrapper):
    """A wrapper to allow passing in content type for file uploads."""

    def __init__(self, file, content_type: str="application/octet-stream") -> None:
        """Initialize a new `FileWrapper` instance.

        Args:
            file: A readable file-like object or byte stream to wrap.
            content_type (str, optional): The MIME type to associate with the
                file. Defaults to `"application/octet-stream"`.

        """
        super().__init__(file, content_type)

    def __repr__(self) -> str:
        """Return a detailed string representation of the instance.

        Returns:
            str: A detailed, unambiguous representation of the wrapper.

        """
        return (f"{self.__class__.__name__}("
                f"file={self._file_stream!r}, "
                f"content_type={self.content_type!r})")

    def __str__(self) -> str:
        """Return a user-friendly string representation of the instance.

        Returns:
            str: A concise, readable representation of the wrapper.

        """
        return (f"{self.__class__.__name__}("
                f"file={self._file_stream!s}, "
                f"content_type={self.content_type!s})")



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AddAvailabilitiesRequest(object):
    """Implementation of the 'AddAvailabilitiesRequest' model.

    Attributes:
        test (bool): When `true`, the request ensures that its parameters are valid
            without affecting real data.  When `false`, the request performs as
            intended and may affect live client data.  (optional) Defaults to false.
        location_id (int): Location of availability.  <br />Not used when
            IsUnavailable is `true`.
        staff_i_ds (List[int]): A list of requested staff IDs.<br />  (optional)
            Defaults to staff ID of user credentials. Use 0 for all.
        program_i_ds (List[int]): A list of program IDs.<br />  (optional) Defaults
            to all.  <br />Not used when IsUnavailable is true.
        start_date_time (datetime): The start date and time of the new availabilities
            or unavailabilities.
        end_date_time (datetime): The end date and time of the new availabilities or
            unavailabilities.
        days_of_week (List[DaysOfWeekEnum]): The days of the week to set.<br />
            (optional) Defaults to all.
        unavailable_description (str): Description of unavalability.  <br />Only used
            when IsUnavailable is true.
        is_unavailable (bool): When `true`, indicates that unavailability is getting
            added. When `false`, indicates that availability is getting added.
            Default: **false**
        public_display (PublicDisplay1Enum): Sets the public display of the
            availability.<br /><ul><li>Show</li><li>Mask</li><li>Hide</li></ul>
            (optional) Defaults to Show.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "test": "Test",
        "location_id": "LocationID",
        "staff_i_ds": "StaffIDs",
        "program_i_ds": "ProgramIDs",
        "start_date_time": "StartDateTime",
        "end_date_time": "EndDateTime",
        "days_of_week": "DaysOfWeek",
        "unavailable_description": "UnavailableDescription",
        "is_unavailable": "IsUnavailable",
        "public_display": "PublicDisplay",
    }

    _optionals = [
        "test",
        "location_id",
        "staff_i_ds",
        "program_i_ds",
        "start_date_time",
        "end_date_time",
        "days_of_week",
        "unavailable_description",
        "is_unavailable",
        "public_display",
    ]

    def __init__(
        self,
        test=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        staff_i_ds=APIHelper.SKIP,
        program_i_ds=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        days_of_week=APIHelper.SKIP,
        unavailable_description=APIHelper.SKIP,
        is_unavailable=APIHelper.SKIP,
        public_display=APIHelper.SKIP):
        """Initialize a AddAvailabilitiesRequest instance."""
        # Initialize members of the class
        if test is not APIHelper.SKIP:
            self.test = test
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if staff_i_ds is not APIHelper.SKIP:
            self.staff_i_ds = staff_i_ds
        if program_i_ds is not APIHelper.SKIP:
            self.program_i_ds = program_i_ds
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if days_of_week is not APIHelper.SKIP:
            self.days_of_week = days_of_week
        if unavailable_description is not APIHelper.SKIP:
            self.unavailable_description = unavailable_description
        if is_unavailable is not APIHelper.SKIP:
            self.is_unavailable = is_unavailable
        if public_display is not APIHelper.SKIP:
            self.public_display = public_display

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationID")\
            if dictionary.get("LocationID")\
                else APIHelper.SKIP
        staff_i_ds =\
            dictionary.get("StaffIDs")\
            if dictionary.get("StaffIDs")\
                else APIHelper.SKIP
        program_i_ds =\
            dictionary.get("ProgramIDs")\
            if dictionary.get("ProgramIDs")\
                else APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        days_of_week =\
            dictionary.get("DaysOfWeek")\
            if dictionary.get("DaysOfWeek")\
                else APIHelper.SKIP
        unavailable_description =\
            dictionary.get("UnavailableDescription")\
            if dictionary.get("UnavailableDescription")\
                else APIHelper.SKIP
        is_unavailable =\
            dictionary.get("IsUnavailable")\
            if "IsUnavailable" in dictionary.keys()\
                else APIHelper.SKIP
        public_display =\
            dictionary.get("PublicDisplay")\
            if dictionary.get("PublicDisplay")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(test,
                   location_id,
                   staff_i_ds,
                   program_i_ds,
                   start_date_time,
                   end_date_time,
                   days_of_week,
                   unavailable_description,
                   is_unavailable,
                   public_display)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _staff_i_ds=(
            self.staff_i_ds
            if hasattr(self, "staff_i_ds")
            else None
        )
        _program_i_ds=(
            self.program_i_ds
            if hasattr(self, "program_i_ds")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _days_of_week=(
            self.days_of_week
            if hasattr(self, "days_of_week")
            else None
        )
        _unavailable_description=(
            self.unavailable_description
            if hasattr(self, "unavailable_description")
            else None
        )
        _is_unavailable=(
            self.is_unavailable
            if hasattr(self, "is_unavailable")
            else None
        )
        _public_display=(
            self.public_display
            if hasattr(self, "public_display")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"test={_test!r}, "
            f"location_id={_location_id!r}, "
            f"staff_i_ds={_staff_i_ds!r}, "
            f"program_i_ds={_program_i_ds!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"days_of_week={_days_of_week!r}, "
            f"unavailable_description={_unavailable_description!r}, "
            f"is_unavailable={_is_unavailable!r}, "
            f"public_display={_public_display!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _staff_i_ds=(
            self.staff_i_ds
            if hasattr(self, "staff_i_ds")
            else None
        )
        _program_i_ds=(
            self.program_i_ds
            if hasattr(self, "program_i_ds")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _days_of_week=(
            self.days_of_week
            if hasattr(self, "days_of_week")
            else None
        )
        _unavailable_description=(
            self.unavailable_description
            if hasattr(self, "unavailable_description")
            else None
        )
        _is_unavailable=(
            self.is_unavailable
            if hasattr(self, "is_unavailable")
            else None
        )
        _public_display=(
            self.public_display
            if hasattr(self, "public_display")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"test={_test!s}, "
            f"location_id={_location_id!s}, "
            f"staff_i_ds={_staff_i_ds!s}, "
            f"program_i_ds={_program_i_ds!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"days_of_week={_days_of_week!s}, "
            f"unavailable_description={_unavailable_description!s}, "
            f"is_unavailable={_is_unavailable!s}, "
            f"public_display={_public_display!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.appointment import (
    Appointment,
)
from mindbodypublicapi.models.class_schedule import (
    ClassSchedule,
)
from mindbodypublicapi.models.mclass import (
    Class,
)
from mindbodypublicapi.models.shopping_cart import (
    ShoppingCart,
)


class CheckoutShoppingCartResponse(object):
    """Implementation of the 'CheckoutShoppingCartResponse' model.

    The API Response model for Checkout Shopping Cart APIs

    Attributes:
        shopping_cart (ShoppingCart): Represents a shopping cart.
        classes (List[Class]): Contains information about the classes.
        appointments (List[Appointment]): Contains information about the appointments.
        enrollments (List[ClassSchedule]): Contains information about enrollment
            class schedules.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "shopping_cart": "ShoppingCart",
        "classes": "Classes",
        "appointments": "Appointments",
        "enrollments": "Enrollments",
    }

    _optionals = [
        "shopping_cart",
        "classes",
        "appointments",
        "enrollments",
    ]

    def __init__(
        self,
        shopping_cart=APIHelper.SKIP,
        classes=APIHelper.SKIP,
        appointments=APIHelper.SKIP,
        enrollments=APIHelper.SKIP):
        """Initialize a CheckoutShoppingCartResponse instance."""
        # Initialize members of the class
        if shopping_cart is not APIHelper.SKIP:
            self.shopping_cart = shopping_cart
        if classes is not APIHelper.SKIP:
            self.classes = classes
        if appointments is not APIHelper.SKIP:
            self.appointments = appointments
        if enrollments is not APIHelper.SKIP:
            self.enrollments = enrollments

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        shopping_cart =\
            ShoppingCart.from_dictionary(
                dictionary.get("ShoppingCart"))\
                if "ShoppingCart" in dictionary.keys()\
                else APIHelper.SKIP
        classes = None
        if dictionary.get("Classes") is not None:
            classes = [
                Class.from_dictionary(x)
                    for x in dictionary.get("Classes")
            ]
        else:
            classes = APIHelper.SKIP
        appointments = None
        if dictionary.get("Appointments") is not None:
            appointments = [
                Appointment.from_dictionary(x)
                    for x in dictionary.get("Appointments")
            ]
        else:
            appointments = APIHelper.SKIP
        enrollments = None
        if dictionary.get("Enrollments") is not None:
            enrollments = [
                ClassSchedule.from_dictionary(x)
                    for x in dictionary.get("Enrollments")
            ]
        else:
            enrollments = APIHelper.SKIP

        # Return an object of this model
        return cls(shopping_cart,
                   classes,
                   appointments,
                   enrollments)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _shopping_cart=(
            self.shopping_cart
            if hasattr(self, "shopping_cart")
            else None
        )
        _classes=(
            self.classes
            if hasattr(self, "classes")
            else None
        )
        _appointments=(
            self.appointments
            if hasattr(self, "appointments")
            else None
        )
        _enrollments=(
            self.enrollments
            if hasattr(self, "enrollments")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"shopping_cart={_shopping_cart!r}, "
            f"classes={_classes!r}, "
            f"appointments={_appointments!r}, "
            f"enrollments={_enrollments!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _shopping_cart=(
            self.shopping_cart
            if hasattr(self, "shopping_cart")
            else None
        )
        _classes=(
            self.classes
            if hasattr(self, "classes")
            else None
        )
        _appointments=(
            self.appointments
            if hasattr(self, "appointments")
            else None
        )
        _enrollments=(
            self.enrollments
            if hasattr(self, "enrollments")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"shopping_cart={_shopping_cart!s}, "
            f"classes={_classes!s}, "
            f"appointments={_appointments!s}, "
            f"enrollments={_enrollments!s}, "
            f")"
        )



"""
 mindbodypublicapi

 This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""
from abc import ABC

from apimatic_core_interfaces.client.http_client_provider import (
    HttpClientProvider as CoreHttpClientProvider,
)


class HttpClientProvider(CoreHttpClientProvider, ABC):
    """
     Defines a contract for providing HTTP client configuration.

     Classes implementing this interface are expected to supply a configured
     HTTP session and timeout value that will be used by the SDK's internal
     HTTP layer when making network requests.

     This allows developers to inject their own custom HTTP clients while
     maintaining compatibility with the SDK's request/response handling.
    """



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class StaffPermissionGroup(object):
    """Implementation of the 'StaffPermissionGroup' model.

    Attributes:
        permission_group_name (str): The name of the permission group.
        ip_restricted (bool): When `true`, the staff member’s permissions are
            restricted to specific IP addresses.<br />  When `false`, the staff
            member’s permissions are not restricted to specific IP addresses.
        allowed_permissions (List[AllowedPermissionEnum]): A list of the permissions
            allowed to the staff member. See [Permission
            Values](https://developers.mindbodyonline.com/PublicDocumentation/V6#eperm
            ission-values) for descriptions of the possible permissions.
        denied_permissions (List[DeniedPermissionEnum]): A list of the permissions
            that the staff member is not allowed to exercise. See [Permission
            Values](https://developers.mindbodyonline.com/PublicDocumentation/V6#eperm
            ission-values) for descriptions of the possible permissions.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "permission_group_name": "PermissionGroupName",
        "ip_restricted": "IpRestricted",
        "allowed_permissions": "AllowedPermissions",
        "denied_permissions": "DeniedPermissions",
    }

    _optionals = [
        "permission_group_name",
        "ip_restricted",
        "allowed_permissions",
        "denied_permissions",
    ]

    def __init__(
        self,
        permission_group_name=APIHelper.SKIP,
        ip_restricted=APIHelper.SKIP,
        allowed_permissions=APIHelper.SKIP,
        denied_permissions=APIHelper.SKIP):
        """Initialize a StaffPermissionGroup instance."""
        # Initialize members of the class
        if permission_group_name is not APIHelper.SKIP:
            self.permission_group_name = permission_group_name
        if ip_restricted is not APIHelper.SKIP:
            self.ip_restricted = ip_restricted
        if allowed_permissions is not APIHelper.SKIP:
            self.allowed_permissions = allowed_permissions
        if denied_permissions is not APIHelper.SKIP:
            self.denied_permissions = denied_permissions

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        permission_group_name =\
            dictionary.get("PermissionGroupName")\
            if dictionary.get("PermissionGroupName")\
                else APIHelper.SKIP
        ip_restricted =\
            dictionary.get("IpRestricted")\
            if "IpRestricted" in dictionary.keys()\
                else APIHelper.SKIP
        allowed_permissions =\
            dictionary.get("AllowedPermissions")\
            if dictionary.get("AllowedPermissions")\
                else APIHelper.SKIP
        denied_permissions =\
            dictionary.get("DeniedPermissions")\
            if dictionary.get("DeniedPermissions")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(permission_group_name,
                   ip_restricted,
                   allowed_permissions,
                   denied_permissions)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _permission_group_name=(
            self.permission_group_name
            if hasattr(self, "permission_group_name")
            else None
        )
        _ip_restricted=(
            self.ip_restricted
            if hasattr(self, "ip_restricted")
            else None
        )
        _allowed_permissions=(
            self.allowed_permissions
            if hasattr(self, "allowed_permissions")
            else None
        )
        _denied_permissions=(
            self.denied_permissions
            if hasattr(self, "denied_permissions")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"permission_group_name={_permission_group_name!r}, "
            f"ip_restricted={_ip_restricted!r}, "
            f"allowed_permissions={_allowed_permissions!r}, "
            f"denied_permissions={_denied_permissions!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _permission_group_name=(
            self.permission_group_name
            if hasattr(self, "permission_group_name")
            else None
        )
        _ip_restricted=(
            self.ip_restricted
            if hasattr(self, "ip_restricted")
            else None
        )
        _allowed_permissions=(
            self.allowed_permissions
            if hasattr(self, "allowed_permissions")
            else None
        )
        _denied_permissions=(
            self.denied_permissions
            if hasattr(self, "denied_permissions")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"permission_group_name={_permission_group_name!s}, "
            f"ip_restricted={_ip_restricted!s}, "
            f"allowed_permissions={_allowed_permissions!s}, "
            f"denied_permissions={_denied_permissions!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class Pagination(object):
    """Implementation of the 'Pagination' model.

    Contains information about the pagination used.

    Attributes:
        page_number (int): Page number of results in dataset.
        page_size (int): Number of results returned in this response.
        total_result_count (int): Total number of results in dataset.
        total_page_count (int): Total number of page in dataset.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "page_number": "PageNumber",
        "page_size": "PageSize",
        "total_result_count": "TotalResultCount",
        "total_page_count": "TotalPageCount",
    }

    _optionals = [
        "page_number",
        "page_size",
        "total_result_count",
        "total_page_count",
    ]

    def __init__(
        self,
        page_number=APIHelper.SKIP,
        page_size=APIHelper.SKIP,
        total_result_count=APIHelper.SKIP,
        total_page_count=APIHelper.SKIP):
        """Initialize a Pagination instance."""
        # Initialize members of the class
        if page_number is not APIHelper.SKIP:
            self.page_number = page_number
        if page_size is not APIHelper.SKIP:
            self.page_size = page_size
        if total_result_count is not APIHelper.SKIP:
            self.total_result_count = total_result_count
        if total_page_count is not APIHelper.SKIP:
            self.total_page_count = total_page_count

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        page_number =\
            dictionary.get("PageNumber")\
            if dictionary.get("PageNumber")\
                else APIHelper.SKIP
        page_size =\
            dictionary.get("PageSize")\
            if dictionary.get("PageSize")\
                else APIHelper.SKIP
        total_result_count =\
            dictionary.get("TotalResultCount")\
            if dictionary.get("TotalResultCount")\
                else APIHelper.SKIP
        total_page_count =\
            dictionary.get("TotalPageCount")\
            if dictionary.get("TotalPageCount")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(page_number,
                   page_size,
                   total_result_count,
                   total_page_count)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _page_number=(
            self.page_number
            if hasattr(self, "page_number")
            else None
        )
        _page_size=(
            self.page_size
            if hasattr(self, "page_size")
            else None
        )
        _total_result_count=(
            self.total_result_count
            if hasattr(self, "total_result_count")
            else None
        )
        _total_page_count=(
            self.total_page_count
            if hasattr(self, "total_page_count")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"page_number={_page_number!r}, "
            f"page_size={_page_size!r}, "
            f"total_result_count={_total_result_count!r}, "
            f"total_page_count={_total_page_count!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _page_number=(
            self.page_number
            if hasattr(self, "page_number")
            else None
        )
        _page_size=(
            self.page_size
            if hasattr(self, "page_size")
            else None
        )
        _total_result_count=(
            self.total_result_count
            if hasattr(self, "total_result_count")
            else None
        )
        _total_page_count=(
            self.total_page_count
            if hasattr(self, "total_page_count")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"page_number={_page_number!s}, "
            f"page_size={_page_size!s}, "
            f"total_result_count={_total_result_count!s}, "
            f"total_page_count={_total_page_count!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.color import Color
from mindbodypublicapi.models.size import Size


class Product(object):
    """Implementation of the 'Product' model.

    Represents a product.

    Attributes:
        product_id (int): The unique ID associated with product.
        id (str): The barcode number of the product. This is the
            `PurchasedItems[].BarcodeId` returned from GET Sales.
        category_id (int): The revenue category ID of the product. Use this ID when
            calling the GET Categories endpoint.
        sub_category_id (int): The SubCategory ID of the product. Use this ID when
            calling the GET Categories endpoint.
        secondary_category_id (int): The SecondaryCategory ID of the product. Use
            this ID when calling the GET Categories endpoint.
        price (float): The price of the product.
        tax_included (float): If tax inclusive-pricing is enabled, this field shows
            how much tax was added to the price. To fetch this value `LocationId`
            must be passed as a query parameter.
        tax_rate (float): The tax rate that was applied to this purchase. To fetch
            this value `LocationId` must be passed as a query parameter.
        group_id (int): The unique ID of the product group.
        name (str): The name of the product.
        online_price (float): The online price of the product.
        short_description (str): A short text description of the product.
        long_description (str): A long, more detailed text description of the product.
        type_group (int): The Type group of the product.
        supplier_id (int): The unique ID of the supplier of product.
        supplier_name (str): The Supplier Name of the product.
        image_url (str): The URL of the image associated with this product.
        color (Color): A color used by products.
        size (Size): The model property of type Size.
        manufacturer_id (str): The ID number attributed to the product by the
            manufacturer.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "product_id": "ProductId",
        "id": "Id",
        "category_id": "CategoryId",
        "sub_category_id": "SubCategoryId",
        "secondary_category_id": "SecondaryCategoryId",
        "price": "Price",
        "tax_included": "TaxIncluded",
        "tax_rate": "TaxRate",
        "group_id": "GroupId",
        "name": "Name",
        "online_price": "OnlinePrice",
        "short_description": "ShortDescription",
        "long_description": "LongDescription",
        "type_group": "TypeGroup",
        "supplier_id": "SupplierId",
        "supplier_name": "SupplierName",
        "image_url": "ImageURL",
        "color": "Color",
        "size": "Size",
        "manufacturer_id": "ManufacturerId",
    }

    _optionals = [
        "product_id",
        "id",
        "category_id",
        "sub_category_id",
        "secondary_category_id",
        "price",
        "tax_included",
        "tax_rate",
        "group_id",
        "name",
        "online_price",
        "short_description",
        "long_description",
        "type_group",
        "supplier_id",
        "supplier_name",
        "image_url",
        "color",
        "size",
        "manufacturer_id",
    ]

    def __init__(
        self,
        product_id=APIHelper.SKIP,
        id=APIHelper.SKIP,
        category_id=APIHelper.SKIP,
        sub_category_id=APIHelper.SKIP,
        secondary_category_id=APIHelper.SKIP,
        price=APIHelper.SKIP,
        tax_included=APIHelper.SKIP,
        tax_rate=APIHelper.SKIP,
        group_id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        online_price=APIHelper.SKIP,
        short_description=APIHelper.SKIP,
        long_description=APIHelper.SKIP,
        type_group=APIHelper.SKIP,
        supplier_id=APIHelper.SKIP,
        supplier_name=APIHelper.SKIP,
        image_url=APIHelper.SKIP,
        color=APIHelper.SKIP,
        size=APIHelper.SKIP,
        manufacturer_id=APIHelper.SKIP):
        """Initialize a Product instance."""
        # Initialize members of the class
        if product_id is not APIHelper.SKIP:
            self.product_id = product_id
        if id is not APIHelper.SKIP:
            self.id = id
        if category_id is not APIHelper.SKIP:
            self.category_id = category_id
        if sub_category_id is not APIHelper.SKIP:
            self.sub_category_id = sub_category_id
        if secondary_category_id is not APIHelper.SKIP:
            self.secondary_category_id = secondary_category_id
        if price is not APIHelper.SKIP:
            self.price = price
        if tax_included is not APIHelper.SKIP:
            self.tax_included = tax_included
        if tax_rate is not APIHelper.SKIP:
            self.tax_rate = tax_rate
        if group_id is not APIHelper.SKIP:
            self.group_id = group_id
        if name is not APIHelper.SKIP:
            self.name = name
        if online_price is not APIHelper.SKIP:
            self.online_price = online_price
        if short_description is not APIHelper.SKIP:
            self.short_description = short_description
        if long_description is not APIHelper.SKIP:
            self.long_description = long_description
        if type_group is not APIHelper.SKIP:
            self.type_group = type_group
        if supplier_id is not APIHelper.SKIP:
            self.supplier_id = supplier_id
        if supplier_name is not APIHelper.SKIP:
            self.supplier_name = supplier_name
        if image_url is not APIHelper.SKIP:
            self.image_url = image_url
        if color is not APIHelper.SKIP:
            self.color = color
        if size is not APIHelper.SKIP:
            self.size = size
        if manufacturer_id is not APIHelper.SKIP:
            self.manufacturer_id = manufacturer_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        product_id =\
            dictionary.get("ProductId")\
            if dictionary.get("ProductId")\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        category_id =\
            dictionary.get("CategoryId")\
            if dictionary.get("CategoryId")\
                else APIHelper.SKIP
        sub_category_id =\
            dictionary.get("SubCategoryId")\
            if dictionary.get("SubCategoryId")\
                else APIHelper.SKIP
        secondary_category_id =\
            dictionary.get("SecondaryCategoryId")\
            if dictionary.get("SecondaryCategoryId")\
                else APIHelper.SKIP
        price =\
            dictionary.get("Price")\
            if dictionary.get("Price")\
                else APIHelper.SKIP
        tax_included =\
            dictionary.get("TaxIncluded")\
            if dictionary.get("TaxIncluded")\
                else APIHelper.SKIP
        tax_rate =\
            dictionary.get("TaxRate")\
            if dictionary.get("TaxRate")\
                else APIHelper.SKIP
        group_id =\
            dictionary.get("GroupId")\
            if dictionary.get("GroupId")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        online_price =\
            dictionary.get("OnlinePrice")\
            if dictionary.get("OnlinePrice")\
                else APIHelper.SKIP
        short_description =\
            dictionary.get("ShortDescription")\
            if dictionary.get("ShortDescription")\
                else APIHelper.SKIP
        long_description =\
            dictionary.get("LongDescription")\
            if dictionary.get("LongDescription")\
                else APIHelper.SKIP
        type_group =\
            dictionary.get("TypeGroup")\
            if dictionary.get("TypeGroup")\
                else APIHelper.SKIP
        supplier_id =\
            dictionary.get("SupplierId")\
            if dictionary.get("SupplierId")\
                else APIHelper.SKIP
        supplier_name =\
            dictionary.get("SupplierName")\
            if dictionary.get("SupplierName")\
                else APIHelper.SKIP
        image_url =\
            dictionary.get("ImageURL")\
            if dictionary.get("ImageURL")\
                else APIHelper.SKIP
        color =\
            Color.from_dictionary(
                dictionary.get("Color"))\
                if "Color" in dictionary.keys()\
                else APIHelper.SKIP
        size =\
            Size.from_dictionary(
                dictionary.get("Size"))\
                if "Size" in dictionary.keys()\
                else APIHelper.SKIP
        manufacturer_id =\
            dictionary.get("ManufacturerId")\
            if dictionary.get("ManufacturerId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(product_id,
                   id,
                   category_id,
                   sub_category_id,
                   secondary_category_id,
                   price,
                   tax_included,
                   tax_rate,
                   group_id,
                   name,
                   online_price,
                   short_description,
                   long_description,
                   type_group,
                   supplier_id,
                   supplier_name,
                   image_url,
                   color,
                   size,
                   manufacturer_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _category_id=(
            self.category_id
            if hasattr(self, "category_id")
            else None
        )
        _sub_category_id=(
            self.sub_category_id
            if hasattr(self, "sub_category_id")
            else None
        )
        _secondary_category_id=(
            self.secondary_category_id
            if hasattr(self, "secondary_category_id")
            else None
        )
        _price=(
            self.price
            if hasattr(self, "price")
            else None
        )
        _tax_included=(
            self.tax_included
            if hasattr(self, "tax_included")
            else None
        )
        _tax_rate=(
            self.tax_rate
            if hasattr(self, "tax_rate")
            else None
        )
        _group_id=(
            self.group_id
            if hasattr(self, "group_id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _online_price=(
            self.online_price
            if hasattr(self, "online_price")
            else None
        )
        _short_description=(
            self.short_description
            if hasattr(self, "short_description")
            else None
        )
        _long_description=(
            self.long_description
            if hasattr(self, "long_description")
            else None
        )
        _type_group=(
            self.type_group
            if hasattr(self, "type_group")
            else None
        )
        _supplier_id=(
            self.supplier_id
            if hasattr(self, "supplier_id")
            else None
        )
        _supplier_name=(
            self.supplier_name
            if hasattr(self, "supplier_name")
            else None
        )
        _image_url=(
            self.image_url
            if hasattr(self, "image_url")
            else None
        )
        _color=(
            self.color
            if hasattr(self, "color")
            else None
        )
        _size=(
            self.size
            if hasattr(self, "size")
            else None
        )
        _manufacturer_id=(
            self.manufacturer_id
            if hasattr(self, "manufacturer_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"product_id={_product_id!r}, "
            f"id={_id!r}, "
            f"category_id={_category_id!r}, "
            f"sub_category_id={_sub_category_id!r}, "
            f"secondary_category_id={_secondary_category_id!r}, "
            f"price={_price!r}, "
            f"tax_included={_tax_included!r}, "
            f"tax_rate={_tax_rate!r}, "
            f"group_id={_group_id!r}, "
            f"name={_name!r}, "
            f"online_price={_online_price!r}, "
            f"short_description={_short_description!r}, "
            f"long_description={_long_description!r}, "
            f"type_group={_type_group!r}, "
            f"supplier_id={_supplier_id!r}, "
            f"supplier_name={_supplier_name!r}, "
            f"image_url={_image_url!r}, "
            f"color={_color!r}, "
            f"size={_size!r}, "
            f"manufacturer_id={_manufacturer_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _category_id=(
            self.category_id
            if hasattr(self, "category_id")
            else None
        )
        _sub_category_id=(
            self.sub_category_id
            if hasattr(self, "sub_category_id")
            else None
        )
        _secondary_category_id=(
            self.secondary_category_id
            if hasattr(self, "secondary_category_id")
            else None
        )
        _price=(
            self.price
            if hasattr(self, "price")
            else None
        )
        _tax_included=(
            self.tax_included
            if hasattr(self, "tax_included")
            else None
        )
        _tax_rate=(
            self.tax_rate
            if hasattr(self, "tax_rate")
            else None
        )
        _group_id=(
            self.group_id
            if hasattr(self, "group_id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _online_price=(
            self.online_price
            if hasattr(self, "online_price")
            else None
        )
        _short_description=(
            self.short_description
            if hasattr(self, "short_description")
            else None
        )
        _long_description=(
            self.long_description
            if hasattr(self, "long_description")
            else None
        )
        _type_group=(
            self.type_group
            if hasattr(self, "type_group")
            else None
        )
        _supplier_id=(
            self.supplier_id
            if hasattr(self, "supplier_id")
            else None
        )
        _supplier_name=(
            self.supplier_name
            if hasattr(self, "supplier_name")
            else None
        )
        _image_url=(
            self.image_url
            if hasattr(self, "image_url")
            else None
        )
        _color=(
            self.color
            if hasattr(self, "color")
            else None
        )
        _size=(
            self.size
            if hasattr(self, "size")
            else None
        )
        _manufacturer_id=(
            self.manufacturer_id
            if hasattr(self, "manufacturer_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"product_id={_product_id!s}, "
            f"id={_id!s}, "
            f"category_id={_category_id!s}, "
            f"sub_category_id={_sub_category_id!s}, "
            f"secondary_category_id={_secondary_category_id!s}, "
            f"price={_price!s}, "
            f"tax_included={_tax_included!s}, "
            f"tax_rate={_tax_rate!s}, "
            f"group_id={_group_id!s}, "
            f"name={_name!s}, "
            f"online_price={_online_price!s}, "
            f"short_description={_short_description!s}, "
            f"long_description={_long_description!s}, "
            f"type_group={_type_group!s}, "
            f"supplier_id={_supplier_id!s}, "
            f"supplier_name={_supplier_name!s}, "
            f"image_url={_image_url!s}, "
            f"color={_color!s}, "
            f"size={_size!s}, "
            f"manufacturer_id={_manufacturer_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class InitiatePurchaseContractRequest(object):
    """Implementation of the 'InitiatePurchaseContractRequest' model.

    Request to initiate a purchase contract.

    Attributes:
        test (bool): When `true`, the Public API validates input information, but
            does not commit it, so no client data is affected.<br />  When `false` or
            omitted, the transaction is committed, and client data is affected.<br />
            This endpoint DOES NOT support the `Test` parameter.<br />  Default:
            **false**
        location_id (int): The ID of the location where the client is purchasing the
            contract; used for AutoPays. If no location ID is supplied, it defaults
            to the online store, represented by a null value.   Default: **null**
            (Online store location)
        client_id (str): The ID of the client. Note that this is not the same as the
            client’s unique ID.
        contract_id (int): The ID of the contract being purchased.
        promotion_code (str): A promotion code, if one applies. Promotion codes are
            applied to items that are both marked as pay now in a contract and are
            discounted by the promotion code. If a pay now item is an autopay item,
            its autopay price is the price at the time of checkout, so, if a
            promotion code was applied, all autopays are scheduled using that
            discounted price.
        promotion_codes (List[str]): Promotion codes, if they apply. Promotion codes
            are applied to items that are both marked as pay now in a contract and
            are discounted by the promotion code. If a pay now item is an autopay
            item, its autopay price is the price at the time of checkout, so, if a
            promotion code was applied, all autopays are scheduled using that
            discounted price.
        send_notifications (bool): When `true`, indicates that email and SMS
            notifications should be sent to the client after purchase.<br />
            Default: **true**
        sales_rep_id (int): The ID of the staff member to be marked as the sales rep
            for this contract sale.
        payment_authentication_callback_url (str): The URL consumer is redirected to
            after the payment.
        payment_method_id (int): The type of alternative payment. Possible values
            are:  * 997 - Indicates that the payment method is iDEAL.  * 801 -
            Indicates that the payment method is Apple Pay.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "contract_id": "ContractId",
        "payment_method_id": "PaymentMethodId",
        "test": "Test",
        "location_id": "LocationId",
        "promotion_code": "PromotionCode",
        "promotion_codes": "PromotionCodes",
        "send_notifications": "SendNotifications",
        "sales_rep_id": "SalesRepId",
        "payment_authentication_callback_url": "PaymentAuthenticationCallbackUrl",
    }

    _optionals = [
        "test",
        "location_id",
        "promotion_code",
        "promotion_codes",
        "send_notifications",
        "sales_rep_id",
        "payment_authentication_callback_url",
    ]

    def __init__(
        self,
        client_id=None,
        contract_id=None,
        payment_method_id=None,
        test=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        promotion_code=APIHelper.SKIP,
        promotion_codes=APIHelper.SKIP,
        send_notifications=APIHelper.SKIP,
        sales_rep_id=APIHelper.SKIP,
        payment_authentication_callback_url=APIHelper.SKIP):
        """Initialize a InitiatePurchaseContractRequest instance."""
        # Initialize members of the class
        if test is not APIHelper.SKIP:
            self.test = test
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        self.client_id = client_id
        self.contract_id = contract_id
        if promotion_code is not APIHelper.SKIP:
            self.promotion_code = promotion_code
        if promotion_codes is not APIHelper.SKIP:
            self.promotion_codes = promotion_codes
        if send_notifications is not APIHelper.SKIP:
            self.send_notifications = send_notifications
        if sales_rep_id is not APIHelper.SKIP:
            self.sales_rep_id = sales_rep_id
        if payment_authentication_callback_url is not APIHelper.SKIP:
            self.payment_authentication_callback_url =\
                 payment_authentication_callback_url
        self.payment_method_id = payment_method_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        contract_id =\
            dictionary.get("ContractId")\
            if dictionary.get("ContractId")\
                else None
        payment_method_id =\
            dictionary.get("PaymentMethodId")\
            if dictionary.get("PaymentMethodId")\
                else None
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        promotion_code =\
            dictionary.get("PromotionCode")\
            if dictionary.get("PromotionCode")\
                else APIHelper.SKIP
        promotion_codes =\
            dictionary.get("PromotionCodes")\
            if dictionary.get("PromotionCodes")\
                else APIHelper.SKIP
        send_notifications =\
            dictionary.get("SendNotifications")\
            if "SendNotifications" in dictionary.keys()\
                else APIHelper.SKIP
        sales_rep_id =\
            dictionary.get("SalesRepId")\
            if dictionary.get("SalesRepId")\
                else APIHelper.SKIP
        payment_authentication_callback_url =\
            dictionary.get("PaymentAuthenticationCallbackUrl")\
            if dictionary.get("PaymentAuthenticationCallbackUrl")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   contract_id,
                   payment_method_id,
                   test,
                   location_id,
                   promotion_code,
                   promotion_codes,
                   send_notifications,
                   sales_rep_id,
                   payment_authentication_callback_url)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _client_id=self.client_id
        _contract_id=self.contract_id
        _promotion_code=(
            self.promotion_code
            if hasattr(self, "promotion_code")
            else None
        )
        _promotion_codes=(
            self.promotion_codes
            if hasattr(self, "promotion_codes")
            else None
        )
        _send_notifications=(
            self.send_notifications
            if hasattr(self, "send_notifications")
            else None
        )
        _sales_rep_id=(
            self.sales_rep_id
            if hasattr(self, "sales_rep_id")
            else None
        )
        _payment_authentication_callback_url=(
            self.payment_authentication_callback_url
            if hasattr(self, "payment_authentication_callback_url")
            else None
        )
        _payment_method_id=self.payment_method_id
        return (
            f"{self.__class__.__name__}("
            f"test={_test!r}, "
            f"location_id={_location_id!r}, "
            f"client_id={_client_id!r}, "
            f"contract_id={_contract_id!r}, "
            f"promotion_code={_promotion_code!r}, "
            f"promotion_codes={_promotion_codes!r}, "
            f"send_notifications={_send_notifications!r}, "
            f"sales_rep_id={_sales_rep_id!r}, "
            f"payment_authentication_callback_url={_payment_authentication_callback_url!r}, "
            f"payment_method_id={_payment_method_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _client_id=self.client_id
        _contract_id=self.contract_id
        _promotion_code=(
            self.promotion_code
            if hasattr(self, "promotion_code")
            else None
        )
        _promotion_codes=(
            self.promotion_codes
            if hasattr(self, "promotion_codes")
            else None
        )
        _send_notifications=(
            self.send_notifications
            if hasattr(self, "send_notifications")
            else None
        )
        _sales_rep_id=(
            self.sales_rep_id
            if hasattr(self, "sales_rep_id")
            else None
        )
        _payment_authentication_callback_url=(
            self.payment_authentication_callback_url
            if hasattr(self, "payment_authentication_callback_url")
            else None
        )
        _payment_method_id=self.payment_method_id
        return (
            f"{self.__class__.__name__}("
            f"test={_test!s}, "
            f"location_id={_location_id!s}, "
            f"client_id={_client_id!s}, "
            f"contract_id={_contract_id!s}, "
            f"promotion_code={_promotion_code!s}, "
            f"promotion_codes={_promotion_codes!s}, "
            f"send_notifications={_send_notifications!s}, "
            f"sales_rep_id={_sales_rep_id!s}, "
            f"payment_authentication_callback_url={_payment_authentication_callback_url!s}, "
            f"payment_method_id={_payment_method_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.appointment import (
    Appointment,
)


class CartItem(object):
    """Implementation of the 'CartItem' model.

    Attributes:
        item (Any): The model property of type Any.
        sales_notes (str): Sales Notes for the Product Purcahsed
        discount_amount (float): The amount of the discount applied to the item.
        visit_ids (List[int]): The IDs of the booked classes, enrollments, or courses
            that were reconciled by this cart item. This list is only returned if a
            valid visit ID was passed in the request’s `VisitIds` list.
        appointment_ids (List[int]): Gets or sets the item.
        appointments (List[Appointment]): The IDs of the appointments that were
            reconciled by this cart item. This list is only returned if a valid
            appointment ID was passed in the request’s `AppointmentIds` list.
        id (int): The item’s ID in the current cart.
        quantity (int): The quantity of the item being purchased.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "item": "Item",
        "sales_notes": "SalesNotes",
        "discount_amount": "DiscountAmount",
        "visit_ids": "VisitIds",
        "appointment_ids": "AppointmentIds",
        "appointments": "Appointments",
        "id": "Id",
        "quantity": "Quantity",
    }

    _optionals = [
        "item",
        "sales_notes",
        "discount_amount",
        "visit_ids",
        "appointment_ids",
        "appointments",
        "id",
        "quantity",
    ]

    def __init__(
        self,
        item=APIHelper.SKIP,
        sales_notes=APIHelper.SKIP,
        discount_amount=APIHelper.SKIP,
        visit_ids=APIHelper.SKIP,
        appointment_ids=APIHelper.SKIP,
        appointments=APIHelper.SKIP,
        id=APIHelper.SKIP,
        quantity=APIHelper.SKIP):
        """Initialize a CartItem instance."""
        # Initialize members of the class
        if item is not APIHelper.SKIP:
            self.item = item
        if sales_notes is not APIHelper.SKIP:
            self.sales_notes = sales_notes
        if discount_amount is not APIHelper.SKIP:
            self.discount_amount = discount_amount
        if visit_ids is not APIHelper.SKIP:
            self.visit_ids = visit_ids
        if appointment_ids is not APIHelper.SKIP:
            self.appointment_ids = appointment_ids
        if appointments is not APIHelper.SKIP:
            self.appointments = appointments
        if id is not APIHelper.SKIP:
            self.id = id
        if quantity is not APIHelper.SKIP:
            self.quantity = quantity

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        item =\
            dictionary.get("Item")\
            if dictionary.get("Item")\
                else APIHelper.SKIP
        sales_notes =\
            dictionary.get("SalesNotes")\
            if dictionary.get("SalesNotes")\
                else APIHelper.SKIP
        discount_amount =\
            dictionary.get("DiscountAmount")\
            if dictionary.get("DiscountAmount")\
                else APIHelper.SKIP
        visit_ids =\
            dictionary.get("VisitIds")\
            if dictionary.get("VisitIds")\
                else APIHelper.SKIP
        appointment_ids =\
            dictionary.get("AppointmentIds")\
            if dictionary.get("AppointmentIds")\
                else APIHelper.SKIP
        appointments = None
        if dictionary.get("Appointments") is not None:
            appointments = [
                Appointment.from_dictionary(x)
                    for x in dictionary.get("Appointments")
            ]
        else:
            appointments = APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        quantity =\
            dictionary.get("Quantity")\
            if dictionary.get("Quantity")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(item,
                   sales_notes,
                   discount_amount,
                   visit_ids,
                   appointment_ids,
                   appointments,
                   id,
                   quantity)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _item=(
            self.item
            if hasattr(self, "item")
            else None
        )
        _sales_notes=(
            self.sales_notes
            if hasattr(self, "sales_notes")
            else None
        )
        _discount_amount=(
            self.discount_amount
            if hasattr(self, "discount_amount")
            else None
        )
        _visit_ids=(
            self.visit_ids
            if hasattr(self, "visit_ids")
            else None
        )
        _appointment_ids=(
            self.appointment_ids
            if hasattr(self, "appointment_ids")
            else None
        )
        _appointments=(
            self.appointments
            if hasattr(self, "appointments")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _quantity=(
            self.quantity
            if hasattr(self, "quantity")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"item={_item!r}, "
            f"sales_notes={_sales_notes!r}, "
            f"discount_amount={_discount_amount!r}, "
            f"visit_ids={_visit_ids!r}, "
            f"appointment_ids={_appointment_ids!r}, "
            f"appointments={_appointments!r}, "
            f"id={_id!r}, "
            f"quantity={_quantity!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _item=(
            self.item
            if hasattr(self, "item")
            else None
        )
        _sales_notes=(
            self.sales_notes
            if hasattr(self, "sales_notes")
            else None
        )
        _discount_amount=(
            self.discount_amount
            if hasattr(self, "discount_amount")
            else None
        )
        _visit_ids=(
            self.visit_ids
            if hasattr(self, "visit_ids")
            else None
        )
        _appointment_ids=(
            self.appointment_ids
            if hasattr(self, "appointment_ids")
            else None
        )
        _appointments=(
            self.appointments
            if hasattr(self, "appointments")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _quantity=(
            self.quantity
            if hasattr(self, "quantity")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"item={_item!s}, "
            f"sales_notes={_sales_notes!s}, "
            f"discount_amount={_discount_amount!s}, "
            f"visit_ids={_visit_ids!s}, "
            f"appointment_ids={_appointment_ids!s}, "
            f"appointments={_appointments!s}, "
            f"id={_id!s}, "
            f"quantity={_quantity!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class ResourceAvailability1(object):
    """Implementation of the 'ResourceAvailability1' model.

    An availability of a resource

    Attributes:
        resource_id (int): Id
        start_date_time (datetime): Starts
        end_date_time (datetime): Ends
        session_type_ids (List[int]): List of SessionTypeIds that this availability
            is restricted to. If empty, no restrictions.
        program_ids (List[int]): List of ProgramIds that this availability is
            restricted to. If empty, no restrictions.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "resource_id": "ResourceId",
        "start_date_time": "StartDateTime",
        "end_date_time": "EndDateTime",
        "session_type_ids": "SessionTypeIds",
        "program_ids": "ProgramIds",
    }

    _optionals = [
        "resource_id",
        "start_date_time",
        "end_date_time",
        "session_type_ids",
        "program_ids",
    ]

    def __init__(
        self,
        resource_id=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        session_type_ids=APIHelper.SKIP,
        program_ids=APIHelper.SKIP):
        """Initialize a ResourceAvailability1 instance."""
        # Initialize members of the class
        if resource_id is not APIHelper.SKIP:
            self.resource_id = resource_id
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if session_type_ids is not APIHelper.SKIP:
            self.session_type_ids = session_type_ids
        if program_ids is not APIHelper.SKIP:
            self.program_ids = program_ids

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        resource_id =\
            dictionary.get("ResourceId")\
            if dictionary.get("ResourceId")\
                else APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        session_type_ids =\
            dictionary.get("SessionTypeIds")\
            if dictionary.get("SessionTypeIds")\
                else APIHelper.SKIP
        program_ids =\
            dictionary.get("ProgramIds")\
            if dictionary.get("ProgramIds")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(resource_id,
                   start_date_time,
                   end_date_time,
                   session_type_ids,
                   program_ids)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _resource_id=(
            self.resource_id
            if hasattr(self, "resource_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _session_type_ids=(
            self.session_type_ids
            if hasattr(self, "session_type_ids")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"resource_id={_resource_id!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"session_type_ids={_session_type_ids!r}, "
            f"program_ids={_program_ids!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _resource_id=(
            self.resource_id
            if hasattr(self, "resource_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _session_type_ids=(
            self.session_type_ids
            if hasattr(self, "session_type_ids")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"resource_id={_resource_id!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"session_type_ids={_session_type_ids!s}, "
            f"program_ids={_program_ids!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetClassVisitsRequest(object):
    """Implementation of the 'GetClassVisitsRequest' model.

    Get class visit request.

    Attributes:
        class_id (int): The class ID.
        last_modified_date (datetime): When included in the request, only records
            modified on or after the `LastModifiedDate` specified are included in the
            response.
        use_site_settings_staff_name (bool): When `true`, the staff DisplayName will
            be populated based on site-level settings.  When `false` or omitted, the
            staff DisplayName will contain only the FirstName.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "class_id": "ClassID",
        "last_modified_date": "LastModifiedDate",
        "use_site_settings_staff_name": "UseSiteSettingsStaffName",
    }

    _optionals = [
        "last_modified_date",
        "use_site_settings_staff_name",
    ]

    def __init__(
        self,
        class_id=None,
        last_modified_date=APIHelper.SKIP,
        use_site_settings_staff_name=APIHelper.SKIP):
        """Initialize a GetClassVisitsRequest instance."""
        # Initialize members of the class
        self.class_id = class_id
        if last_modified_date is not APIHelper.SKIP:
            self.last_modified_date =\
                 APIHelper.apply_datetime_converter(
                last_modified_date, APIHelper.RFC3339DateTime)\
                 if last_modified_date else None
        if use_site_settings_staff_name is not APIHelper.SKIP:
            self.use_site_settings_staff_name = use_site_settings_staff_name

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        class_id =\
            dictionary.get("ClassID")\
            if dictionary.get("ClassID")\
                else None
        last_modified_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("LastModifiedDate")).datetime\
            if dictionary.get("LastModifiedDate") else APIHelper.SKIP
        use_site_settings_staff_name =\
            dictionary.get("UseSiteSettingsStaffName")\
            if "UseSiteSettingsStaffName" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(class_id,
                   last_modified_date,
                   use_site_settings_staff_name)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _class_id=self.class_id
        _last_modified_date=(
            self.last_modified_date
            if hasattr(self, "last_modified_date")
            else None
        )
        _use_site_settings_staff_name=(
            self.use_site_settings_staff_name
            if hasattr(self, "use_site_settings_staff_name")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_id={_class_id!r}, "
            f"last_modified_date={_last_modified_date!r}, "
            f"use_site_settings_staff_name={_use_site_settings_staff_name!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _class_id=self.class_id
        _last_modified_date=(
            self.last_modified_date
            if hasattr(self, "last_modified_date")
            else None
        )
        _use_site_settings_staff_name=(
            self.use_site_settings_staff_name
            if hasattr(self, "use_site_settings_staff_name")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_id={_class_id!s}, "
            f"last_modified_date={_last_modified_date!s}, "
            f"use_site_settings_staff_name={_use_site_settings_staff_name!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class ClientSuspensionInfo(object):
    """Implementation of the 'ClientSuspensionInfo' model.

    A Client DTO with Suspension Informatoin

    Attributes:
        booking_suspended (bool): When 'true', indicates that the client is suspended
            from booking
        suspension_start_date (str): Indicates the Date that BookingSuspension starts
            'YYYY-MM-DD'
        suspension_end_date (str): Indicates the Date that BookingSuspension ends
            'YYYY-MM-DD'

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "booking_suspended": "BookingSuspended",
        "suspension_start_date": "SuspensionStartDate",
        "suspension_end_date": "SuspensionEndDate",
    }

    _optionals = [
        "booking_suspended",
        "suspension_start_date",
        "suspension_end_date",
    ]

    def __init__(
        self,
        booking_suspended=APIHelper.SKIP,
        suspension_start_date=APIHelper.SKIP,
        suspension_end_date=APIHelper.SKIP):
        """Initialize a ClientSuspensionInfo instance."""
        # Initialize members of the class
        if booking_suspended is not APIHelper.SKIP:
            self.booking_suspended = booking_suspended
        if suspension_start_date is not APIHelper.SKIP:
            self.suspension_start_date = suspension_start_date
        if suspension_end_date is not APIHelper.SKIP:
            self.suspension_end_date = suspension_end_date

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        booking_suspended =\
            dictionary.get("BookingSuspended")\
            if "BookingSuspended" in dictionary.keys()\
                else APIHelper.SKIP
        suspension_start_date =\
            dictionary.get("SuspensionStartDate")\
            if dictionary.get("SuspensionStartDate")\
                else APIHelper.SKIP
        suspension_end_date =\
            dictionary.get("SuspensionEndDate")\
            if dictionary.get("SuspensionEndDate")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(booking_suspended,
                   suspension_start_date,
                   suspension_end_date)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _booking_suspended=(
            self.booking_suspended
            if hasattr(self, "booking_suspended")
            else None
        )
        _suspension_start_date=(
            self.suspension_start_date
            if hasattr(self, "suspension_start_date")
            else None
        )
        _suspension_end_date=(
            self.suspension_end_date
            if hasattr(self, "suspension_end_date")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"booking_suspended={_booking_suspended!r}, "
            f"suspension_start_date={_suspension_start_date!r}, "
            f"suspension_end_date={_suspension_end_date!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _booking_suspended=(
            self.booking_suspended
            if hasattr(self, "booking_suspended")
            else None
        )
        _suspension_start_date=(
            self.suspension_start_date
            if hasattr(self, "suspension_start_date")
            else None
        )
        _suspension_end_date=(
            self.suspension_end_date
            if hasattr(self, "suspension_end_date")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"booking_suspended={_booking_suspended!s}, "
            f"suspension_start_date={_suspension_start_date!s}, "
            f"suspension_end_date={_suspension_end_date!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.update_contact_log_comment import (
    UpdateContactLogComment,
)
from mindbodypublicapi.models.update_contact_log_type import (
    UpdateContactLogType,
)


class UpdateContactLogRequest(object):
    """Implementation of the 'UpdateContactLogRequest' model.

    Attributes:
        id (int): The ID of the contact log being updated.
        test (bool): When `true`, indicates that this is a test request and no data
            is inserted into the subscriber’s database.<br />  When `false`, the
            database is updated.
        assigned_to_staff_id (int): The ID of the staff member to whom the contact
            log is now being assigned.
        text (str): The contact log’s new text.
        contact_name (str): The name of the new person to be contacted by the
            assigned staff member.
        followup_by_date (datetime): The new date by which the assigned staff member
            should complete this contact log.
        contact_method (str): The new method by which the client wants to be
            contacted.
        is_complete (bool): When `true`, indicates that the contact log is complete.
            When `false`, indicates the contact log isn’t complete.
        comments (List[UpdateContactLogComment]): Contains information about the
            comments being updated or added to the contact log. Comments that have an
            ID of `0` are added to the contact log.
        types (List[UpdateContactLogType]): Contains information about the contact
            logs types being assigned to the contact log, in addition to the contact
            log types that are already assigned.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "test": "Test",
        "assigned_to_staff_id": "AssignedToStaffId",
        "text": "Text",
        "contact_name": "ContactName",
        "followup_by_date": "FollowupByDate",
        "contact_method": "ContactMethod",
        "is_complete": "IsComplete",
        "comments": "Comments",
        "types": "Types",
    }

    _optionals = [
        "id",
        "test",
        "assigned_to_staff_id",
        "text",
        "contact_name",
        "followup_by_date",
        "contact_method",
        "is_complete",
        "comments",
        "types",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        test=APIHelper.SKIP,
        assigned_to_staff_id=APIHelper.SKIP,
        text=APIHelper.SKIP,
        contact_name=APIHelper.SKIP,
        followup_by_date=APIHelper.SKIP,
        contact_method=APIHelper.SKIP,
        is_complete=APIHelper.SKIP,
        comments=APIHelper.SKIP,
        types=APIHelper.SKIP):
        """Initialize a UpdateContactLogRequest instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if test is not APIHelper.SKIP:
            self.test = test
        if assigned_to_staff_id is not APIHelper.SKIP:
            self.assigned_to_staff_id = assigned_to_staff_id
        if text is not APIHelper.SKIP:
            self.text = text
        if contact_name is not APIHelper.SKIP:
            self.contact_name = contact_name
        if followup_by_date is not APIHelper.SKIP:
            self.followup_by_date =\
                 APIHelper.apply_datetime_converter(
                followup_by_date, APIHelper.RFC3339DateTime)\
                 if followup_by_date else None
        if contact_method is not APIHelper.SKIP:
            self.contact_method = contact_method
        if is_complete is not APIHelper.SKIP:
            self.is_complete = is_complete
        if comments is not APIHelper.SKIP:
            self.comments = comments
        if types is not APIHelper.SKIP:
            self.types = types

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        assigned_to_staff_id =\
            dictionary.get("AssignedToStaffId")\
            if dictionary.get("AssignedToStaffId")\
                else APIHelper.SKIP
        text =\
            dictionary.get("Text")\
            if dictionary.get("Text")\
                else APIHelper.SKIP
        contact_name =\
            dictionary.get("ContactName")\
            if dictionary.get("ContactName")\
                else APIHelper.SKIP
        followup_by_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("FollowupByDate")).datetime\
            if dictionary.get("FollowupByDate") else APIHelper.SKIP
        contact_method =\
            dictionary.get("ContactMethod")\
            if dictionary.get("ContactMethod")\
                else APIHelper.SKIP
        is_complete =\
            dictionary.get("IsComplete")\
            if "IsComplete" in dictionary.keys()\
                else APIHelper.SKIP
        comments = None
        if dictionary.get("Comments") is not None:
            comments = [
                UpdateContactLogComment.from_dictionary(x)
                    for x in dictionary.get("Comments")
            ]
        else:
            comments = APIHelper.SKIP
        types = None
        if dictionary.get("Types") is not None:
            types = [
                UpdateContactLogType.from_dictionary(x)
                    for x in dictionary.get("Types")
            ]
        else:
            types = APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   test,
                   assigned_to_staff_id,
                   text,
                   contact_name,
                   followup_by_date,
                   contact_method,
                   is_complete,
                   comments,
                   types)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _assigned_to_staff_id=(
            self.assigned_to_staff_id
            if hasattr(self, "assigned_to_staff_id")
            else None
        )
        _text=(
            self.text
            if hasattr(self, "text")
            else None
        )
        _contact_name=(
            self.contact_name
            if hasattr(self, "contact_name")
            else None
        )
        _followup_by_date=(
            self.followup_by_date
            if hasattr(self, "followup_by_date")
            else None
        )
        _contact_method=(
            self.contact_method
            if hasattr(self, "contact_method")
            else None
        )
        _is_complete=(
            self.is_complete
            if hasattr(self, "is_complete")
            else None
        )
        _comments=(
            self.comments
            if hasattr(self, "comments")
            else None
        )
        _types=(
            self.types
            if hasattr(self, "types")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"test={_test!r}, "
            f"assigned_to_staff_id={_assigned_to_staff_id!r}, "
            f"text={_text!r}, "
            f"contact_name={_contact_name!r}, "
            f"followup_by_date={_followup_by_date!r}, "
            f"contact_method={_contact_method!r}, "
            f"is_complete={_is_complete!r}, "
            f"comments={_comments!r}, "
            f"types={_types!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _assigned_to_staff_id=(
            self.assigned_to_staff_id
            if hasattr(self, "assigned_to_staff_id")
            else None
        )
        _text=(
            self.text
            if hasattr(self, "text")
            else None
        )
        _contact_name=(
            self.contact_name
            if hasattr(self, "contact_name")
            else None
        )
        _followup_by_date=(
            self.followup_by_date
            if hasattr(self, "followup_by_date")
            else None
        )
        _contact_method=(
            self.contact_method
            if hasattr(self, "contact_method")
            else None
        )
        _is_complete=(
            self.is_complete
            if hasattr(self, "is_complete")
            else None
        )
        _comments=(
            self.comments
            if hasattr(self, "comments")
            else None
        )
        _types=(
            self.types
            if hasattr(self, "types")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"test={_test!s}, "
            f"assigned_to_staff_id={_assigned_to_staff_id!s}, "
            f"text={_text!s}, "
            f"contact_name={_contact_name!s}, "
            f"followup_by_date={_followup_by_date!s}, "
            f"contact_method={_contact_method!s}, "
            f"is_complete={_is_complete!s}, "
            f"comments={_comments!s}, "
            f"types={_types!s}, "
            f")"
        )
